#pragma once

#define ICON_MIN_FA 0xf000
#define ICON_MAX_FA 0xf950
#define ICON_FA_ABACUS "\xef\x99\x80"	// U+f640
#define ICON_FA_ACORN "\xef\x9a\xae"	// U+f6ae
#define ICON_FA_AD "\xef\x99\x81"	// U+f641
#define ICON_FA_ADDRESS_BOOK "\xef\x8a\xb9"	// U+f2b9
#define ICON_FA_ADDRESS_CARD "\xef\x8a\xbb"	// U+f2bb
#define ICON_FA_ADJUST "\xef\x81\x82"	// U+f042
#define ICON_FA_AIR_CONDITIONER "\xef\xa3\xb4"	// U+f8f4
#define ICON_FA_AIR_FRESHENER "\xef\x97\x90"	// U+f5d0
#define ICON_FA_ALARM_CLOCK "\xef\x8d\x8e"	// U+f34e
#define ICON_FA_ALARM_EXCLAMATION "\xef\xa1\x83"	// U+f843
#define ICON_FA_ALARM_PLUS "\xef\xa1\x84"	// U+f844
#define ICON_FA_ALARM_SNOOZE "\xef\xa1\x85"	// U+f845
#define ICON_FA_ALBUM "\xef\xa2\x9f"	// U+f89f
#define ICON_FA_ALBUM_COLLECTION "\xef\xa2\xa0"	// U+f8a0
#define ICON_FA_ALICORN "\xef\x9a\xb0"	// U+f6b0
#define ICON_FA_ALIEN "\xef\xa3\xb5"	// U+f8f5
#define ICON_FA_ALIEN_MONSTER "\xef\xa3\xb6"	// U+f8f6
#define ICON_FA_ALIGN_CENTER "\xef\x80\xb7"	// U+f037
#define ICON_FA_ALIGN_JUSTIFY "\xef\x80\xb9"	// U+f039
#define ICON_FA_ALIGN_LEFT "\xef\x80\xb6"	// U+f036
#define ICON_FA_ALIGN_RIGHT "\xef\x80\xb8"	// U+f038
#define ICON_FA_ALIGN_SLASH "\xef\xa1\x86"	// U+f846
#define ICON_FA_ALLERGIES "\xef\x91\xa1"	// U+f461
#define ICON_FA_AMBULANCE "\xef\x83\xb9"	// U+f0f9
#define ICON_FA_AMERICAN_SIGN_LANGUAGE_INTERPRETING "\xef\x8a\xa3"	// U+f2a3
#define ICON_FA_AMP_GUITAR "\xef\xa2\xa1"	// U+f8a1
#define ICON_FA_ANALYTICS "\xef\x99\x83"	// U+f643
#define ICON_FA_ANCHOR "\xef\x84\xbd"	// U+f13d
#define ICON_FA_ANGEL "\xef\x9d\xb9"	// U+f779
#define ICON_FA_ANGLE_DOUBLE_DOWN "\xef\x84\x83"	// U+f103
#define ICON_FA_ANGLE_DOUBLE_LEFT "\xef\x84\x80"	// U+f100
#define ICON_FA_ANGLE_DOUBLE_RIGHT "\xef\x84\x81"	// U+f101
#define ICON_FA_ANGLE_DOUBLE_UP "\xef\x84\x82"	// U+f102
#define ICON_FA_ANGLE_DOWN "\xef\x84\x87"	// U+f107
#define ICON_FA_ANGLE_LEFT "\xef\x84\x84"	// U+f104
#define ICON_FA_ANGLE_RIGHT "\xef\x84\x85"	// U+f105
#define ICON_FA_ANGLE_UP "\xef\x84\x86"	// U+f106
#define ICON_FA_ANGRY "\xef\x95\x96"	// U+f556
#define ICON_FA_ANKH "\xef\x99\x84"	// U+f644
#define ICON_FA_APPLE_ALT "\xef\x97\x91"	// U+f5d1
#define ICON_FA_APPLE_CRATE "\xef\x9a\xb1"	// U+f6b1
#define ICON_FA_ARCHIVE "\xef\x86\x87"	// U+f187
#define ICON_FA_ARCHWAY "\xef\x95\x97"	// U+f557
#define ICON_FA_ARROW_ALT_CIRCLE_DOWN "\xef\x8d\x98"	// U+f358
#define ICON_FA_ARROW_ALT_CIRCLE_LEFT "\xef\x8d\x99"	// U+f359
#define ICON_FA_ARROW_ALT_CIRCLE_RIGHT "\xef\x8d\x9a"	// U+f35a
#define ICON_FA_ARROW_ALT_CIRCLE_UP "\xef\x8d\x9b"	// U+f35b
#define ICON_FA_ARROW_ALT_DOWN "\xef\x8d\x94"	// U+f354
#define ICON_FA_ARROW_ALT_FROM_BOTTOM "\xef\x8d\x86"	// U+f346
#define ICON_FA_ARROW_ALT_FROM_LEFT "\xef\x8d\x87"	// U+f347
#define ICON_FA_ARROW_ALT_FROM_RIGHT "\xef\x8d\x88"	// U+f348
#define ICON_FA_ARROW_ALT_FROM_TOP "\xef\x8d\x89"	// U+f349
#define ICON_FA_ARROW_ALT_LEFT "\xef\x8d\x95"	// U+f355
#define ICON_FA_ARROW_ALT_RIGHT "\xef\x8d\x96"	// U+f356
#define ICON_FA_ARROW_ALT_SQUARE_DOWN "\xef\x8d\x90"	// U+f350
#define ICON_FA_ARROW_ALT_SQUARE_LEFT "\xef\x8d\x91"	// U+f351
#define ICON_FA_ARROW_ALT_SQUARE_RIGHT "\xef\x8d\x92"	// U+f352
#define ICON_FA_ARROW_ALT_SQUARE_UP "\xef\x8d\x93"	// U+f353
#define ICON_FA_ARROW_ALT_TO_BOTTOM "\xef\x8d\x8a"	// U+f34a
#define ICON_FA_ARROW_ALT_TO_LEFT "\xef\x8d\x8b"	// U+f34b
#define ICON_FA_ARROW_ALT_TO_RIGHT "\xef\x8d\x8c"	// U+f34c
#define ICON_FA_ARROW_ALT_TO_TOP "\xef\x8d\x8d"	// U+f34d
#define ICON_FA_ARROW_ALT_UP "\xef\x8d\x97"	// U+f357
#define ICON_FA_ARROW_CIRCLE_DOWN "\xef\x82\xab"	// U+f0ab
#define ICON_FA_ARROW_CIRCLE_LEFT "\xef\x82\xa8"	// U+f0a8
#define ICON_FA_ARROW_CIRCLE_RIGHT "\xef\x82\xa9"	// U+f0a9
#define ICON_FA_ARROW_CIRCLE_UP "\xef\x82\xaa"	// U+f0aa
#define ICON_FA_ARROW_DOWN "\xef\x81\xa3"	// U+f063
#define ICON_FA_ARROW_FROM_BOTTOM "\xef\x8d\x82"	// U+f342
#define ICON_FA_ARROW_FROM_LEFT "\xef\x8d\x83"	// U+f343
#define ICON_FA_ARROW_FROM_RIGHT "\xef\x8d\x84"	// U+f344
#define ICON_FA_ARROW_FROM_TOP "\xef\x8d\x85"	// U+f345
#define ICON_FA_ARROW_LEFT "\xef\x81\xa0"	// U+f060
#define ICON_FA_ARROW_RIGHT "\xef\x81\xa1"	// U+f061
#define ICON_FA_ARROW_SQUARE_DOWN "\xef\x8c\xb9"	// U+f339
#define ICON_FA_ARROW_SQUARE_LEFT "\xef\x8c\xba"	// U+f33a
#define ICON_FA_ARROW_SQUARE_RIGHT "\xef\x8c\xbb"	// U+f33b
#define ICON_FA_ARROW_SQUARE_UP "\xef\x8c\xbc"	// U+f33c
#define ICON_FA_ARROW_TO_BOTTOM "\xef\x8c\xbd"	// U+f33d
#define ICON_FA_ARROW_TO_LEFT "\xef\x8c\xbe"	// U+f33e
#define ICON_FA_ARROW_TO_RIGHT "\xef\x8d\x80"	// U+f340
#define ICON_FA_ARROW_TO_TOP "\xef\x8d\x81"	// U+f341
#define ICON_FA_ARROW_UP "\xef\x81\xa2"	// U+f062
#define ICON_FA_ARROWS "\xef\x81\x87"	// U+f047
#define ICON_FA_ARROWS_ALT "\xef\x82\xb2"	// U+f0b2
#define ICON_FA_ARROWS_ALT_H "\xef\x8c\xb7"	// U+f337
#define ICON_FA_ARROWS_ALT_V "\xef\x8c\xb8"	// U+f338
#define ICON_FA_ARROWS_H "\xef\x81\xbe"	// U+f07e
#define ICON_FA_ARROWS_V "\xef\x81\xbd"	// U+f07d
#define ICON_FA_ASSISTIVE_LISTENING_SYSTEMS "\xef\x8a\xa2"	// U+f2a2
#define ICON_FA_ASTERISK "\xef\x81\xa9"	// U+f069
#define ICON_FA_AT "\xef\x87\xba"	// U+f1fa
#define ICON_FA_ATLAS "\xef\x95\x98"	// U+f558
#define ICON_FA_ATOM "\xef\x97\x92"	// U+f5d2
#define ICON_FA_ATOM_ALT "\xef\x97\x93"	// U+f5d3
#define ICON_FA_AUDIO_DESCRIPTION "\xef\x8a\x9e"	// U+f29e
#define ICON_FA_AWARD "\xef\x95\x99"	// U+f559
#define ICON_FA_AXE "\xef\x9a\xb2"	// U+f6b2
#define ICON_FA_AXE_BATTLE "\xef\x9a\xb3"	// U+f6b3
#define ICON_FA_BABY "\xef\x9d\xbc"	// U+f77c
#define ICON_FA_BABY_CARRIAGE "\xef\x9d\xbd"	// U+f77d
#define ICON_FA_BACKPACK "\xef\x97\x94"	// U+f5d4
#define ICON_FA_BACKSPACE "\xef\x95\x9a"	// U+f55a
#define ICON_FA_BACKWARD "\xef\x81\x8a"	// U+f04a
#define ICON_FA_BACON "\xef\x9f\xa5"	// U+f7e5
#define ICON_FA_BADGE "\xef\x8c\xb5"	// U+f335
#define ICON_FA_BADGE_CHECK "\xef\x8c\xb6"	// U+f336
#define ICON_FA_BADGE_DOLLAR "\xef\x99\x85"	// U+f645
#define ICON_FA_BADGE_PERCENT "\xef\x99\x86"	// U+f646
#define ICON_FA_BADGE_SHERIFF "\xef\xa2\xa2"	// U+f8a2
#define ICON_FA_BADGER_HONEY "\xef\x9a\xb4"	// U+f6b4
#define ICON_FA_BAGS_SHOPPING "\xef\xa1\x87"	// U+f847
#define ICON_FA_BAHAI "\xef\x99\xa6"	// U+f666
#define ICON_FA_BALANCE_SCALE "\xef\x89\x8e"	// U+f24e
#define ICON_FA_BALANCE_SCALE_LEFT "\xef\x94\x95"	// U+f515
#define ICON_FA_BALANCE_SCALE_RIGHT "\xef\x94\x96"	// U+f516
#define ICON_FA_BALL_PILE "\xef\x9d\xbe"	// U+f77e
#define ICON_FA_BALLOT "\xef\x9c\xb2"	// U+f732
#define ICON_FA_BALLOT_CHECK "\xef\x9c\xb3"	// U+f733
#define ICON_FA_BAN "\xef\x81\x9e"	// U+f05e
#define ICON_FA_BAND_AID "\xef\x91\xa2"	// U+f462
#define ICON_FA_BANJO "\xef\xa2\xa3"	// U+f8a3
#define ICON_FA_BARCODE "\xef\x80\xaa"	// U+f02a
#define ICON_FA_BARCODE_ALT "\xef\x91\xa3"	// U+f463
#define ICON_FA_BARCODE_READ "\xef\x91\xa4"	// U+f464
#define ICON_FA_BARCODE_SCAN "\xef\x91\xa5"	// U+f465
#define ICON_FA_BARS "\xef\x83\x89"	// U+f0c9
#define ICON_FA_BASEBALL "\xef\x90\xb2"	// U+f432
#define ICON_FA_BASEBALL_BALL "\xef\x90\xb3"	// U+f433
#define ICON_FA_BASKETBALL_BALL "\xef\x90\xb4"	// U+f434
#define ICON_FA_BASKETBALL_HOOP "\xef\x90\xb5"	// U+f435
#define ICON_FA_BAT "\xef\x9a\xb5"	// U+f6b5
#define ICON_FA_BATH "\xef\x8b\x8d"	// U+f2cd
#define ICON_FA_BATTERY_BOLT "\xef\x8d\xb6"	// U+f376
#define ICON_FA_BATTERY_EMPTY "\xef\x89\x84"	// U+f244
#define ICON_FA_BATTERY_FULL "\xef\x89\x80"	// U+f240
#define ICON_FA_BATTERY_HALF "\xef\x89\x82"	// U+f242
#define ICON_FA_BATTERY_QUARTER "\xef\x89\x83"	// U+f243
#define ICON_FA_BATTERY_SLASH "\xef\x8d\xb7"	// U+f377
#define ICON_FA_BATTERY_THREE_QUARTERS "\xef\x89\x81"	// U+f241
#define ICON_FA_BED "\xef\x88\xb6"	// U+f236
#define ICON_FA_BED_ALT "\xef\xa3\xb7"	// U+f8f7
#define ICON_FA_BED_BUNK "\xef\xa3\xb8"	// U+f8f8
#define ICON_FA_BED_EMPTY "\xef\xa3\xb9"	// U+f8f9
#define ICON_FA_BEER "\xef\x83\xbc"	// U+f0fc
#define ICON_FA_BELL "\xef\x83\xb3"	// U+f0f3
#define ICON_FA_BELL_EXCLAMATION "\xef\xa1\x88"	// U+f848
#define ICON_FA_BELL_ON "\xef\xa3\xba"	// U+f8fa
#define ICON_FA_BELL_PLUS "\xef\xa1\x89"	// U+f849
#define ICON_FA_BELL_SCHOOL "\xef\x97\x95"	// U+f5d5
#define ICON_FA_BELL_SCHOOL_SLASH "\xef\x97\x96"	// U+f5d6
#define ICON_FA_BELL_SLASH "\xef\x87\xb6"	// U+f1f6
#define ICON_FA_BELLS "\xef\x9d\xbf"	// U+f77f
#define ICON_FA_BETAMAX "\xef\xa2\xa4"	// U+f8a4
#define ICON_FA_BEZIER_CURVE "\xef\x95\x9b"	// U+f55b
#define ICON_FA_BIBLE "\xef\x99\x87"	// U+f647
#define ICON_FA_BICYCLE "\xef\x88\x86"	// U+f206
#define ICON_FA_BIKING "\xef\xa1\x8a"	// U+f84a
#define ICON_FA_BIKING_MOUNTAIN "\xef\xa1\x8b"	// U+f84b
#define ICON_FA_BINOCULARS "\xef\x87\xa5"	// U+f1e5
#define ICON_FA_BIOHAZARD "\xef\x9e\x80"	// U+f780
#define ICON_FA_BIRTHDAY_CAKE "\xef\x87\xbd"	// U+f1fd
#define ICON_FA_BLANKET "\xef\x92\x98"	// U+f498
#define ICON_FA_BLENDER "\xef\x94\x97"	// U+f517
#define ICON_FA_BLENDER_PHONE "\xef\x9a\xb6"	// U+f6b6
#define ICON_FA_BLIND "\xef\x8a\x9d"	// U+f29d
#define ICON_FA_BLINDS "\xef\xa3\xbb"	// U+f8fb
#define ICON_FA_BLINDS_OPEN "\xef\xa3\xbc"	// U+f8fc
#define ICON_FA_BLINDS_RAISED "\xef\xa3\xbd"	// U+f8fd
#define ICON_FA_BLOG "\xef\x9e\x81"	// U+f781
#define ICON_FA_BOLD "\xef\x80\xb2"	// U+f032
#define ICON_FA_BOLT "\xef\x83\xa7"	// U+f0e7
#define ICON_FA_BOMB "\xef\x87\xa2"	// U+f1e2
#define ICON_FA_BONE "\xef\x97\x97"	// U+f5d7
#define ICON_FA_BONE_BREAK "\xef\x97\x98"	// U+f5d8
#define ICON_FA_BONG "\xef\x95\x9c"	// U+f55c
#define ICON_FA_BOOK "\xef\x80\xad"	// U+f02d
#define ICON_FA_BOOK_ALT "\xef\x97\x99"	// U+f5d9
#define ICON_FA_BOOK_DEAD "\xef\x9a\xb7"	// U+f6b7
#define ICON_FA_BOOK_HEART "\xef\x92\x99"	// U+f499
#define ICON_FA_BOOK_MEDICAL "\xef\x9f\xa6"	// U+f7e6
#define ICON_FA_BOOK_OPEN "\xef\x94\x98"	// U+f518
#define ICON_FA_BOOK_READER "\xef\x97\x9a"	// U+f5da
#define ICON_FA_BOOK_SPELLS "\xef\x9a\xb8"	// U+f6b8
#define ICON_FA_BOOK_USER "\xef\x9f\xa7"	// U+f7e7
#define ICON_FA_BOOKMARK "\xef\x80\xae"	// U+f02e
#define ICON_FA_BOOKS "\xef\x97\x9b"	// U+f5db
#define ICON_FA_BOOKS_MEDICAL "\xef\x9f\xa8"	// U+f7e8
#define ICON_FA_BOOMBOX "\xef\xa2\xa5"	// U+f8a5
#define ICON_FA_BOOT "\xef\x9e\x82"	// U+f782
#define ICON_FA_BOOTH_CURTAIN "\xef\x9c\xb4"	// U+f734
#define ICON_FA_BORDER_ALL "\xef\xa1\x8c"	// U+f84c
#define ICON_FA_BORDER_BOTTOM "\xef\xa1\x8d"	// U+f84d
#define ICON_FA_BORDER_CENTER_H "\xef\xa2\x9c"	// U+f89c
#define ICON_FA_BORDER_CENTER_V "\xef\xa2\x9d"	// U+f89d
#define ICON_FA_BORDER_INNER "\xef\xa1\x8e"	// U+f84e
#define ICON_FA_BORDER_LEFT "\xef\xa1\x8f"	// U+f84f
#define ICON_FA_BORDER_NONE "\xef\xa1\x90"	// U+f850
#define ICON_FA_BORDER_OUTER "\xef\xa1\x91"	// U+f851
#define ICON_FA_BORDER_RIGHT "\xef\xa1\x92"	// U+f852
#define ICON_FA_BORDER_STYLE "\xef\xa1\x93"	// U+f853
#define ICON_FA_BORDER_STYLE_ALT "\xef\xa1\x94"	// U+f854
#define ICON_FA_BORDER_TOP "\xef\xa1\x95"	// U+f855
#define ICON_FA_BOW_ARROW "\xef\x9a\xb9"	// U+f6b9
#define ICON_FA_BOWLING_BALL "\xef\x90\xb6"	// U+f436
#define ICON_FA_BOWLING_PINS "\xef\x90\xb7"	// U+f437
#define ICON_FA_BOX "\xef\x91\xa6"	// U+f466
#define ICON_FA_BOX_ALT "\xef\x92\x9a"	// U+f49a
#define ICON_FA_BOX_BALLOT "\xef\x9c\xb5"	// U+f735
#define ICON_FA_BOX_CHECK "\xef\x91\xa7"	// U+f467
#define ICON_FA_BOX_FRAGILE "\xef\x92\x9b"	// U+f49b
#define ICON_FA_BOX_FULL "\xef\x92\x9c"	// U+f49c
#define ICON_FA_BOX_HEART "\xef\x92\x9d"	// U+f49d
#define ICON_FA_BOX_OPEN "\xef\x92\x9e"	// U+f49e
#define ICON_FA_BOX_UP "\xef\x92\x9f"	// U+f49f
#define ICON_FA_BOX_USD "\xef\x92\xa0"	// U+f4a0
#define ICON_FA_BOXES "\xef\x91\xa8"	// U+f468
#define ICON_FA_BOXES_ALT "\xef\x92\xa1"	// U+f4a1
#define ICON_FA_BOXING_GLOVE "\xef\x90\xb8"	// U+f438
#define ICON_FA_BRACKETS "\xef\x9f\xa9"	// U+f7e9
#define ICON_FA_BRACKETS_CURLY "\xef\x9f\xaa"	// U+f7ea
#define ICON_FA_BRAILLE "\xef\x8a\xa1"	// U+f2a1
#define ICON_FA_BRAIN "\xef\x97\x9c"	// U+f5dc
#define ICON_FA_BREAD_LOAF "\xef\x9f\xab"	// U+f7eb
#define ICON_FA_BREAD_SLICE "\xef\x9f\xac"	// U+f7ec
#define ICON_FA_BRIEFCASE "\xef\x82\xb1"	// U+f0b1
#define ICON_FA_BRIEFCASE_MEDICAL "\xef\x91\xa9"	// U+f469
#define ICON_FA_BRING_FORWARD "\xef\xa1\x96"	// U+f856
#define ICON_FA_BRING_FRONT "\xef\xa1\x97"	// U+f857
#define ICON_FA_BROADCAST_TOWER "\xef\x94\x99"	// U+f519
#define ICON_FA_BROOM "\xef\x94\x9a"	// U+f51a
#define ICON_FA_BROWSER "\xef\x8d\xbe"	// U+f37e
#define ICON_FA_BRUSH "\xef\x95\x9d"	// U+f55d
#define ICON_FA_BUG "\xef\x86\x88"	// U+f188
#define ICON_FA_BUILDING "\xef\x86\xad"	// U+f1ad
#define ICON_FA_BULLHORN "\xef\x82\xa1"	// U+f0a1
#define ICON_FA_BULLSEYE "\xef\x85\x80"	// U+f140
#define ICON_FA_BULLSEYE_ARROW "\xef\x99\x88"	// U+f648
#define ICON_FA_BULLSEYE_POINTER "\xef\x99\x89"	// U+f649
#define ICON_FA_BURGER_SODA "\xef\xa1\x98"	// U+f858
#define ICON_FA_BURN "\xef\x91\xaa"	// U+f46a
#define ICON_FA_BURRITO "\xef\x9f\xad"	// U+f7ed
#define ICON_FA_BUS "\xef\x88\x87"	// U+f207
#define ICON_FA_BUS_ALT "\xef\x95\x9e"	// U+f55e
#define ICON_FA_BUS_SCHOOL "\xef\x97\x9d"	// U+f5dd
#define ICON_FA_BUSINESS_TIME "\xef\x99\x8a"	// U+f64a
#define ICON_FA_CABINET_FILING "\xef\x99\x8b"	// U+f64b
#define ICON_FA_CACTUS "\xef\xa2\xa7"	// U+f8a7
#define ICON_FA_CALCULATOR "\xef\x87\xac"	// U+f1ec
#define ICON_FA_CALCULATOR_ALT "\xef\x99\x8c"	// U+f64c
#define ICON_FA_CALENDAR "\xef\x84\xb3"	// U+f133
#define ICON_FA_CALENDAR_ALT "\xef\x81\xb3"	// U+f073
#define ICON_FA_CALENDAR_CHECK "\xef\x89\xb4"	// U+f274
#define ICON_FA_CALENDAR_DAY "\xef\x9e\x83"	// U+f783
#define ICON_FA_CALENDAR_EDIT "\xef\x8c\xb3"	// U+f333
#define ICON_FA_CALENDAR_EXCLAMATION "\xef\x8c\xb4"	// U+f334
#define ICON_FA_CALENDAR_MINUS "\xef\x89\xb2"	// U+f272
#define ICON_FA_CALENDAR_PLUS "\xef\x89\xb1"	// U+f271
#define ICON_FA_CALENDAR_STAR "\xef\x9c\xb6"	// U+f736
#define ICON_FA_CALENDAR_TIMES "\xef\x89\xb3"	// U+f273
#define ICON_FA_CALENDAR_WEEK "\xef\x9e\x84"	// U+f784
#define ICON_FA_CAMCORDER "\xef\xa2\xa8"	// U+f8a8
#define ICON_FA_CAMERA "\xef\x80\xb0"	// U+f030
#define ICON_FA_CAMERA_ALT "\xef\x8c\xb2"	// U+f332
#define ICON_FA_CAMERA_HOME "\xef\xa3\xbe"	// U+f8fe
#define ICON_FA_CAMERA_MOVIE "\xef\xa2\xa9"	// U+f8a9
#define ICON_FA_CAMERA_POLAROID "\xef\xa2\xaa"	// U+f8aa
#define ICON_FA_CAMERA_RETRO "\xef\x82\x83"	// U+f083
#define ICON_FA_CAMPFIRE "\xef\x9a\xba"	// U+f6ba
#define ICON_FA_CAMPGROUND "\xef\x9a\xbb"	// U+f6bb
#define ICON_FA_CANDLE_HOLDER "\xef\x9a\xbc"	// U+f6bc
#define ICON_FA_CANDY_CANE "\xef\x9e\x86"	// U+f786
#define ICON_FA_CANDY_CORN "\xef\x9a\xbd"	// U+f6bd
#define ICON_FA_CANNABIS "\xef\x95\x9f"	// U+f55f
#define ICON_FA_CAPSULES "\xef\x91\xab"	// U+f46b
#define ICON_FA_CAR "\xef\x86\xb9"	// U+f1b9
#define ICON_FA_CAR_ALT "\xef\x97\x9e"	// U+f5de
#define ICON_FA_CAR_BATTERY "\xef\x97\x9f"	// U+f5df
#define ICON_FA_CAR_BUILDING "\xef\xa1\x99"	// U+f859
#define ICON_FA_CAR_BUMP "\xef\x97\xa0"	// U+f5e0
#define ICON_FA_CAR_BUS "\xef\xa1\x9a"	// U+f85a
#define ICON_FA_CAR_CRASH "\xef\x97\xa1"	// U+f5e1
#define ICON_FA_CAR_GARAGE "\xef\x97\xa2"	// U+f5e2
#define ICON_FA_CAR_MECHANIC "\xef\x97\xa3"	// U+f5e3
#define ICON_FA_CAR_SIDE "\xef\x97\xa4"	// U+f5e4
#define ICON_FA_CAR_TILT "\xef\x97\xa5"	// U+f5e5
#define ICON_FA_CAR_WASH "\xef\x97\xa6"	// U+f5e6
#define ICON_FA_CARAVAN "\xef\xa3\xbf"	// U+f8ff
#define ICON_FA_CARAVAN_ALT "\xef\xa4\x80"	// U+f900
#define ICON_FA_CARET_CIRCLE_DOWN "\xef\x8c\xad"	// U+f32d
#define ICON_FA_CARET_CIRCLE_LEFT "\xef\x8c\xae"	// U+f32e
#define ICON_FA_CARET_CIRCLE_RIGHT "\xef\x8c\xb0"	// U+f330
#define ICON_FA_CARET_CIRCLE_UP "\xef\x8c\xb1"	// U+f331
#define ICON_FA_CARET_DOWN "\xef\x83\x97"	// U+f0d7
#define ICON_FA_CARET_LEFT "\xef\x83\x99"	// U+f0d9
#define ICON_FA_CARET_RIGHT "\xef\x83\x9a"	// U+f0da
#define ICON_FA_CARET_SQUARE_DOWN "\xef\x85\x90"	// U+f150
#define ICON_FA_CARET_SQUARE_LEFT "\xef\x86\x91"	// U+f191
#define ICON_FA_CARET_SQUARE_RIGHT "\xef\x85\x92"	// U+f152
#define ICON_FA_CARET_SQUARE_UP "\xef\x85\x91"	// U+f151
#define ICON_FA_CARET_UP "\xef\x83\x98"	// U+f0d8
#define ICON_FA_CARROT "\xef\x9e\x87"	// U+f787
#define ICON_FA_CARS "\xef\xa1\x9b"	// U+f85b
#define ICON_FA_CART_ARROW_DOWN "\xef\x88\x98"	// U+f218
#define ICON_FA_CART_PLUS "\xef\x88\x97"	// U+f217
#define ICON_FA_CASH_REGISTER "\xef\x9e\x88"	// U+f788
#define ICON_FA_CASSETTE_TAPE "\xef\xa2\xab"	// U+f8ab
#define ICON_FA_CAT "\xef\x9a\xbe"	// U+f6be
#define ICON_FA_CAT_SPACE "\xef\xa4\x81"	// U+f901
#define ICON_FA_CAULDRON "\xef\x9a\xbf"	// U+f6bf
#define ICON_FA_CCTV "\xef\xa2\xac"	// U+f8ac
#define ICON_FA_CERTIFICATE "\xef\x82\xa3"	// U+f0a3
#define ICON_FA_CHAIR "\xef\x9b\x80"	// U+f6c0
#define ICON_FA_CHAIR_OFFICE "\xef\x9b\x81"	// U+f6c1
#define ICON_FA_CHALKBOARD "\xef\x94\x9b"	// U+f51b
#define ICON_FA_CHALKBOARD_TEACHER "\xef\x94\x9c"	// U+f51c
#define ICON_FA_CHARGING_STATION "\xef\x97\xa7"	// U+f5e7
#define ICON_FA_CHART_AREA "\xef\x87\xbe"	// U+f1fe
#define ICON_FA_CHART_BAR "\xef\x82\x80"	// U+f080
#define ICON_FA_CHART_LINE "\xef\x88\x81"	// U+f201
#define ICON_FA_CHART_LINE_DOWN "\xef\x99\x8d"	// U+f64d
#define ICON_FA_CHART_NETWORK "\xef\x9e\x8a"	// U+f78a
#define ICON_FA_CHART_PIE "\xef\x88\x80"	// U+f200
#define ICON_FA_CHART_PIE_ALT "\xef\x99\x8e"	// U+f64e
#define ICON_FA_CHART_SCATTER "\xef\x9f\xae"	// U+f7ee
#define ICON_FA_CHECK "\xef\x80\x8c"	// U+f00c
#define ICON_FA_CHECK_CIRCLE "\xef\x81\x98"	// U+f058
#define ICON_FA_CHECK_DOUBLE "\xef\x95\xa0"	// U+f560
#define ICON_FA_CHECK_SQUARE "\xef\x85\x8a"	// U+f14a
#define ICON_FA_CHEESE "\xef\x9f\xaf"	// U+f7ef
#define ICON_FA_CHEESE_SWISS "\xef\x9f\xb0"	// U+f7f0
#define ICON_FA_CHEESEBURGER "\xef\x9f\xb1"	// U+f7f1
#define ICON_FA_CHESS "\xef\x90\xb9"	// U+f439
#define ICON_FA_CHESS_BISHOP "\xef\x90\xba"	// U+f43a
#define ICON_FA_CHESS_BISHOP_ALT "\xef\x90\xbb"	// U+f43b
#define ICON_FA_CHESS_BOARD "\xef\x90\xbc"	// U+f43c
#define ICON_FA_CHESS_CLOCK "\xef\x90\xbd"	// U+f43d
#define ICON_FA_CHESS_CLOCK_ALT "\xef\x90\xbe"	// U+f43e
#define ICON_FA_CHESS_KING "\xef\x90\xbf"	// U+f43f
#define ICON_FA_CHESS_KING_ALT "\xef\x91\x80"	// U+f440
#define ICON_FA_CHESS_KNIGHT "\xef\x91\x81"	// U+f441
#define ICON_FA_CHESS_KNIGHT_ALT "\xef\x91\x82"	// U+f442
#define ICON_FA_CHESS_PAWN "\xef\x91\x83"	// U+f443
#define ICON_FA_CHESS_PAWN_ALT "\xef\x91\x84"	// U+f444
#define ICON_FA_CHESS_QUEEN "\xef\x91\x85"	// U+f445
#define ICON_FA_CHESS_QUEEN_ALT "\xef\x91\x86"	// U+f446
#define ICON_FA_CHESS_ROOK "\xef\x91\x87"	// U+f447
#define ICON_FA_CHESS_ROOK_ALT "\xef\x91\x88"	// U+f448
#define ICON_FA_CHEVRON_CIRCLE_DOWN "\xef\x84\xba"	// U+f13a
#define ICON_FA_CHEVRON_CIRCLE_LEFT "\xef\x84\xb7"	// U+f137
#define ICON_FA_CHEVRON_CIRCLE_RIGHT "\xef\x84\xb8"	// U+f138
#define ICON_FA_CHEVRON_CIRCLE_UP "\xef\x84\xb9"	// U+f139
#define ICON_FA_CHEVRON_DOUBLE_DOWN "\xef\x8c\xa2"	// U+f322
#define ICON_FA_CHEVRON_DOUBLE_LEFT "\xef\x8c\xa3"	// U+f323
#define ICON_FA_CHEVRON_DOUBLE_RIGHT "\xef\x8c\xa4"	// U+f324
#define ICON_FA_CHEVRON_DOUBLE_UP "\xef\x8c\xa5"	// U+f325
#define ICON_FA_CHEVRON_DOWN "\xef\x81\xb8"	// U+f078
#define ICON_FA_CHEVRON_LEFT "\xef\x81\x93"	// U+f053
#define ICON_FA_CHEVRON_RIGHT "\xef\x81\x94"	// U+f054
#define ICON_FA_CHEVRON_SQUARE_DOWN "\xef\x8c\xa9"	// U+f329
#define ICON_FA_CHEVRON_SQUARE_LEFT "\xef\x8c\xaa"	// U+f32a
#define ICON_FA_CHEVRON_SQUARE_RIGHT "\xef\x8c\xab"	// U+f32b
#define ICON_FA_CHEVRON_SQUARE_UP "\xef\x8c\xac"	// U+f32c
#define ICON_FA_CHEVRON_UP "\xef\x81\xb7"	// U+f077
#define ICON_FA_CHILD "\xef\x86\xae"	// U+f1ae
#define ICON_FA_CHIMNEY "\xef\x9e\x8b"	// U+f78b
#define ICON_FA_CHURCH "\xef\x94\x9d"	// U+f51d
#define ICON_FA_CIRCLE "\xef\x84\x91"	// U+f111
#define ICON_FA_CIRCLE_NOTCH "\xef\x87\x8e"	// U+f1ce
#define ICON_FA_CITY "\xef\x99\x8f"	// U+f64f
#define ICON_FA_CLARINET "\xef\xa2\xad"	// U+f8ad
#define ICON_FA_CLAW_MARKS "\xef\x9b\x82"	// U+f6c2
#define ICON_FA_CLINIC_MEDICAL "\xef\x9f\xb2"	// U+f7f2
#define ICON_FA_CLIPBOARD "\xef\x8c\xa8"	// U+f328
#define ICON_FA_CLIPBOARD_CHECK "\xef\x91\xac"	// U+f46c
#define ICON_FA_CLIPBOARD_LIST "\xef\x91\xad"	// U+f46d
#define ICON_FA_CLIPBOARD_LIST_CHECK "\xef\x9c\xb7"	// U+f737
#define ICON_FA_CLIPBOARD_PRESCRIPTION "\xef\x97\xa8"	// U+f5e8
#define ICON_FA_CLIPBOARD_USER "\xef\x9f\xb3"	// U+f7f3
#define ICON_FA_CLOCK "\xef\x80\x97"	// U+f017
#define ICON_FA_CLONE "\xef\x89\x8d"	// U+f24d
#define ICON_FA_CLOSED_CAPTIONING "\xef\x88\x8a"	// U+f20a
#define ICON_FA_CLOUD "\xef\x83\x82"	// U+f0c2
#define ICON_FA_CLOUD_DOWNLOAD "\xef\x83\xad"	// U+f0ed
#define ICON_FA_CLOUD_DOWNLOAD_ALT "\xef\x8e\x81"	// U+f381
#define ICON_FA_CLOUD_DRIZZLE "\xef\x9c\xb8"	// U+f738
#define ICON_FA_CLOUD_HAIL "\xef\x9c\xb9"	// U+f739
#define ICON_FA_CLOUD_HAIL_MIXED "\xef\x9c\xba"	// U+f73a
#define ICON_FA_CLOUD_MEATBALL "\xef\x9c\xbb"	// U+f73b
#define ICON_FA_CLOUD_MOON "\xef\x9b\x83"	// U+f6c3
#define ICON_FA_CLOUD_MOON_RAIN "\xef\x9c\xbc"	// U+f73c
#define ICON_FA_CLOUD_MUSIC "\xef\xa2\xae"	// U+f8ae
#define ICON_FA_CLOUD_RAIN "\xef\x9c\xbd"	// U+f73d
#define ICON_FA_CLOUD_RAINBOW "\xef\x9c\xbe"	// U+f73e
#define ICON_FA_CLOUD_SHOWERS "\xef\x9c\xbf"	// U+f73f
#define ICON_FA_CLOUD_SHOWERS_HEAVY "\xef\x9d\x80"	// U+f740
#define ICON_FA_CLOUD_SLEET "\xef\x9d\x81"	// U+f741
#define ICON_FA_CLOUD_SNOW "\xef\x9d\x82"	// U+f742
#define ICON_FA_CLOUD_SUN "\xef\x9b\x84"	// U+f6c4
#define ICON_FA_CLOUD_SUN_RAIN "\xef\x9d\x83"	// U+f743
#define ICON_FA_CLOUD_UPLOAD "\xef\x83\xae"	// U+f0ee
#define ICON_FA_CLOUD_UPLOAD_ALT "\xef\x8e\x82"	// U+f382
#define ICON_FA_CLOUDS "\xef\x9d\x84"	// U+f744
#define ICON_FA_CLOUDS_MOON "\xef\x9d\x85"	// U+f745
#define ICON_FA_CLOUDS_SUN "\xef\x9d\x86"	// U+f746
#define ICON_FA_CLUB "\xef\x8c\xa7"	// U+f327
#define ICON_FA_COCKTAIL "\xef\x95\xa1"	// U+f561
#define ICON_FA_CODE "\xef\x84\xa1"	// U+f121
#define ICON_FA_CODE_BRANCH "\xef\x84\xa6"	// U+f126
#define ICON_FA_CODE_COMMIT "\xef\x8e\x86"	// U+f386
#define ICON_FA_CODE_MERGE "\xef\x8e\x87"	// U+f387
#define ICON_FA_COFFEE "\xef\x83\xb4"	// U+f0f4
#define ICON_FA_COFFEE_POT "\xef\xa4\x82"	// U+f902
#define ICON_FA_COFFEE_TOGO "\xef\x9b\x85"	// U+f6c5
#define ICON_FA_COFFIN "\xef\x9b\x86"	// U+f6c6
#define ICON_FA_COG "\xef\x80\x93"	// U+f013
#define ICON_FA_COGS "\xef\x82\x85"	// U+f085
#define ICON_FA_COIN "\xef\xa1\x9c"	// U+f85c
#define ICON_FA_COINS "\xef\x94\x9e"	// U+f51e
#define ICON_FA_COLUMNS "\xef\x83\x9b"	// U+f0db
#define ICON_FA_COMET "\xef\xa4\x83"	// U+f903
#define ICON_FA_COMMENT "\xef\x81\xb5"	// U+f075
#define ICON_FA_COMMENT_ALT "\xef\x89\xba"	// U+f27a
#define ICON_FA_COMMENT_ALT_CHECK "\xef\x92\xa2"	// U+f4a2
#define ICON_FA_COMMENT_ALT_DOLLAR "\xef\x99\x90"	// U+f650
#define ICON_FA_COMMENT_ALT_DOTS "\xef\x92\xa3"	// U+f4a3
#define ICON_FA_COMMENT_ALT_EDIT "\xef\x92\xa4"	// U+f4a4
#define ICON_FA_COMMENT_ALT_EXCLAMATION "\xef\x92\xa5"	// U+f4a5
#define ICON_FA_COMMENT_ALT_LINES "\xef\x92\xa6"	// U+f4a6
#define ICON_FA_COMMENT_ALT_MEDICAL "\xef\x9f\xb4"	// U+f7f4
#define ICON_FA_COMMENT_ALT_MINUS "\xef\x92\xa7"	// U+f4a7
#define ICON_FA_COMMENT_ALT_MUSIC "\xef\xa2\xaf"	// U+f8af
#define ICON_FA_COMMENT_ALT_PLUS "\xef\x92\xa8"	// U+f4a8
#define ICON_FA_COMMENT_ALT_SLASH "\xef\x92\xa9"	// U+f4a9
#define ICON_FA_COMMENT_ALT_SMILE "\xef\x92\xaa"	// U+f4aa
#define ICON_FA_COMMENT_ALT_TIMES "\xef\x92\xab"	// U+f4ab
#define ICON_FA_COMMENT_CHECK "\xef\x92\xac"	// U+f4ac
#define ICON_FA_COMMENT_DOLLAR "\xef\x99\x91"	// U+f651
#define ICON_FA_COMMENT_DOTS "\xef\x92\xad"	// U+f4ad
#define ICON_FA_COMMENT_EDIT "\xef\x92\xae"	// U+f4ae
#define ICON_FA_COMMENT_EXCLAMATION "\xef\x92\xaf"	// U+f4af
#define ICON_FA_COMMENT_LINES "\xef\x92\xb0"	// U+f4b0
#define ICON_FA_COMMENT_MEDICAL "\xef\x9f\xb5"	// U+f7f5
#define ICON_FA_COMMENT_MINUS "\xef\x92\xb1"	// U+f4b1
#define ICON_FA_COMMENT_MUSIC "\xef\xa2\xb0"	// U+f8b0
#define ICON_FA_COMMENT_PLUS "\xef\x92\xb2"	// U+f4b2
#define ICON_FA_COMMENT_SLASH "\xef\x92\xb3"	// U+f4b3
#define ICON_FA_COMMENT_SMILE "\xef\x92\xb4"	// U+f4b4
#define ICON_FA_COMMENT_TIMES "\xef\x92\xb5"	// U+f4b5
#define ICON_FA_COMMENTS "\xef\x82\x86"	// U+f086
#define ICON_FA_COMMENTS_ALT "\xef\x92\xb6"	// U+f4b6
#define ICON_FA_COMMENTS_ALT_DOLLAR "\xef\x99\x92"	// U+f652
#define ICON_FA_COMMENTS_DOLLAR "\xef\x99\x93"	// U+f653
#define ICON_FA_COMPACT_DISC "\xef\x94\x9f"	// U+f51f
#define ICON_FA_COMPASS "\xef\x85\x8e"	// U+f14e
#define ICON_FA_COMPASS_SLASH "\xef\x97\xa9"	// U+f5e9
#define ICON_FA_COMPRESS "\xef\x81\xa6"	// U+f066
#define ICON_FA_COMPRESS_ALT "\xef\x90\xa2"	// U+f422
#define ICON_FA_COMPRESS_ARROWS_ALT "\xef\x9e\x8c"	// U+f78c
#define ICON_FA_COMPRESS_WIDE "\xef\x8c\xa6"	// U+f326
#define ICON_FA_COMPUTER_CLASSIC "\xef\xa2\xb1"	// U+f8b1
#define ICON_FA_COMPUTER_SPEAKER "\xef\xa2\xb2"	// U+f8b2
#define ICON_FA_CONCIERGE_BELL "\xef\x95\xa2"	// U+f562
#define ICON_FA_CONSTRUCTION "\xef\xa1\x9d"	// U+f85d
#define ICON_FA_CONTAINER_STORAGE "\xef\x92\xb7"	// U+f4b7
#define ICON_FA_CONVEYOR_BELT "\xef\x91\xae"	// U+f46e
#define ICON_FA_CONVEYOR_BELT_ALT "\xef\x91\xaf"	// U+f46f
#define ICON_FA_COOKIE "\xef\x95\xa3"	// U+f563
#define ICON_FA_COOKIE_BITE "\xef\x95\xa4"	// U+f564
#define ICON_FA_COPY "\xef\x83\x85"	// U+f0c5
#define ICON_FA_COPYRIGHT "\xef\x87\xb9"	// U+f1f9
#define ICON_FA_CORN "\xef\x9b\x87"	// U+f6c7
#define ICON_FA_COUCH "\xef\x92\xb8"	// U+f4b8
#define ICON_FA_COW "\xef\x9b\x88"	// U+f6c8
#define ICON_FA_COWBELL "\xef\xa2\xb3"	// U+f8b3
#define ICON_FA_COWBELL_MORE "\xef\xa2\xb4"	// U+f8b4
#define ICON_FA_CREDIT_CARD "\xef\x82\x9d"	// U+f09d
#define ICON_FA_CREDIT_CARD_BLANK "\xef\x8e\x89"	// U+f389
#define ICON_FA_CREDIT_CARD_FRONT "\xef\x8e\x8a"	// U+f38a
#define ICON_FA_CRICKET "\xef\x91\x89"	// U+f449
#define ICON_FA_CROISSANT "\xef\x9f\xb6"	// U+f7f6
#define ICON_FA_CROP "\xef\x84\xa5"	// U+f125
#define ICON_FA_CROP_ALT "\xef\x95\xa5"	// U+f565
#define ICON_FA_CROSS "\xef\x99\x94"	// U+f654
#define ICON_FA_CROSSHAIRS "\xef\x81\x9b"	// U+f05b
#define ICON_FA_CROW "\xef\x94\xa0"	// U+f520
#define ICON_FA_CROWN "\xef\x94\xa1"	// U+f521
#define ICON_FA_CRUTCH "\xef\x9f\xb7"	// U+f7f7
#define ICON_FA_CRUTCHES "\xef\x9f\xb8"	// U+f7f8
#define ICON_FA_CUBE "\xef\x86\xb2"	// U+f1b2
#define ICON_FA_CUBES "\xef\x86\xb3"	// U+f1b3
#define ICON_FA_CURLING "\xef\x91\x8a"	// U+f44a
#define ICON_FA_CUT "\xef\x83\x84"	// U+f0c4
#define ICON_FA_DAGGER "\xef\x9b\x8b"	// U+f6cb
#define ICON_FA_DATABASE "\xef\x87\x80"	// U+f1c0
#define ICON_FA_DEAF "\xef\x8a\xa4"	// U+f2a4
#define ICON_FA_DEBUG "\xef\x9f\xb9"	// U+f7f9
#define ICON_FA_DEER "\xef\x9e\x8e"	// U+f78e
#define ICON_FA_DEER_RUDOLPH "\xef\x9e\x8f"	// U+f78f
#define ICON_FA_DEMOCRAT "\xef\x9d\x87"	// U+f747
#define ICON_FA_DESKTOP "\xef\x84\x88"	// U+f108
#define ICON_FA_DESKTOP_ALT "\xef\x8e\x90"	// U+f390
#define ICON_FA_DEWPOINT "\xef\x9d\x88"	// U+f748
#define ICON_FA_DHARMACHAKRA "\xef\x99\x95"	// U+f655
#define ICON_FA_DIAGNOSES "\xef\x91\xb0"	// U+f470
#define ICON_FA_DIAMOND "\xef\x88\x99"	// U+f219
#define ICON_FA_DICE "\xef\x94\xa2"	// U+f522
#define ICON_FA_DICE_D10 "\xef\x9b\x8d"	// U+f6cd
#define ICON_FA_DICE_D12 "\xef\x9b\x8e"	// U+f6ce
#define ICON_FA_DICE_D20 "\xef\x9b\x8f"	// U+f6cf
#define ICON_FA_DICE_D4 "\xef\x9b\x90"	// U+f6d0
#define ICON_FA_DICE_D6 "\xef\x9b\x91"	// U+f6d1
#define ICON_FA_DICE_D8 "\xef\x9b\x92"	// U+f6d2
#define ICON_FA_DICE_FIVE "\xef\x94\xa3"	// U+f523
#define ICON_FA_DICE_FOUR "\xef\x94\xa4"	// U+f524
#define ICON_FA_DICE_ONE "\xef\x94\xa5"	// U+f525
#define ICON_FA_DICE_SIX "\xef\x94\xa6"	// U+f526
#define ICON_FA_DICE_THREE "\xef\x94\xa7"	// U+f527
#define ICON_FA_DICE_TWO "\xef\x94\xa8"	// U+f528
#define ICON_FA_DIGGING "\xef\xa1\x9e"	// U+f85e
#define ICON_FA_DIGITAL_TACHOGRAPH "\xef\x95\xa6"	// U+f566
#define ICON_FA_DIPLOMA "\xef\x97\xaa"	// U+f5ea
#define ICON_FA_DIRECTIONS "\xef\x97\xab"	// U+f5eb
#define ICON_FA_DISC_DRIVE "\xef\xa2\xb5"	// U+f8b5
#define ICON_FA_DISEASE "\xef\x9f\xba"	// U+f7fa
#define ICON_FA_DIVIDE "\xef\x94\xa9"	// U+f529
#define ICON_FA_DIZZY "\xef\x95\xa7"	// U+f567
#define ICON_FA_DNA "\xef\x91\xb1"	// U+f471
#define ICON_FA_DO_NOT_ENTER "\xef\x97\xac"	// U+f5ec
#define ICON_FA_DOG "\xef\x9b\x93"	// U+f6d3
#define ICON_FA_DOG_LEASHED "\xef\x9b\x94"	// U+f6d4
#define ICON_FA_DOLLAR_SIGN "\xef\x85\x95"	// U+f155
#define ICON_FA_DOLLY "\xef\x91\xb2"	// U+f472
#define ICON_FA_DOLLY_EMPTY "\xef\x91\xb3"	// U+f473
#define ICON_FA_DOLLY_FLATBED "\xef\x91\xb4"	// U+f474
#define ICON_FA_DOLLY_FLATBED_ALT "\xef\x91\xb5"	// U+f475
#define ICON_FA_DOLLY_FLATBED_EMPTY "\xef\x91\xb6"	// U+f476
#define ICON_FA_DONATE "\xef\x92\xb9"	// U+f4b9
#define ICON_FA_DOOR_CLOSED "\xef\x94\xaa"	// U+f52a
#define ICON_FA_DOOR_OPEN "\xef\x94\xab"	// U+f52b
#define ICON_FA_DOT_CIRCLE "\xef\x86\x92"	// U+f192
#define ICON_FA_DOVE "\xef\x92\xba"	// U+f4ba
#define ICON_FA_DOWNLOAD "\xef\x80\x99"	// U+f019
#define ICON_FA_DRAFTING_COMPASS "\xef\x95\xa8"	// U+f568
#define ICON_FA_DRAGON "\xef\x9b\x95"	// U+f6d5
#define ICON_FA_DRAW_CIRCLE "\xef\x97\xad"	// U+f5ed
#define ICON_FA_DRAW_POLYGON "\xef\x97\xae"	// U+f5ee
#define ICON_FA_DRAW_SQUARE "\xef\x97\xaf"	// U+f5ef
#define ICON_FA_DREIDEL "\xef\x9e\x92"	// U+f792
#define ICON_FA_DRONE "\xef\xa1\x9f"	// U+f85f
#define ICON_FA_DRONE_ALT "\xef\xa1\xa0"	// U+f860
#define ICON_FA_DRUM "\xef\x95\xa9"	// U+f569
#define ICON_FA_DRUM_STEELPAN "\xef\x95\xaa"	// U+f56a
#define ICON_FA_DRUMSTICK "\xef\x9b\x96"	// U+f6d6
#define ICON_FA_DRUMSTICK_BITE "\xef\x9b\x97"	// U+f6d7
#define ICON_FA_DRYER "\xef\xa1\xa1"	// U+f861
#define ICON_FA_DRYER_ALT "\xef\xa1\xa2"	// U+f862
#define ICON_FA_DUCK "\xef\x9b\x98"	// U+f6d8
#define ICON_FA_DUMBBELL "\xef\x91\x8b"	// U+f44b
#define ICON_FA_DUMPSTER "\xef\x9e\x93"	// U+f793
#define ICON_FA_DUMPSTER_FIRE "\xef\x9e\x94"	// U+f794
#define ICON_FA_DUNGEON "\xef\x9b\x99"	// U+f6d9
#define ICON_FA_EAR "\xef\x97\xb0"	// U+f5f0
#define ICON_FA_EAR_MUFFS "\xef\x9e\x95"	// U+f795
#define ICON_FA_ECLIPSE "\xef\x9d\x89"	// U+f749
#define ICON_FA_ECLIPSE_ALT "\xef\x9d\x8a"	// U+f74a
#define ICON_FA_EDIT "\xef\x81\x84"	// U+f044
#define ICON_FA_EGG "\xef\x9f\xbb"	// U+f7fb
#define ICON_FA_EGG_FRIED "\xef\x9f\xbc"	// U+f7fc
#define ICON_FA_EJECT "\xef\x81\x92"	// U+f052
#define ICON_FA_ELEPHANT "\xef\x9b\x9a"	// U+f6da
#define ICON_FA_ELLIPSIS_H "\xef\x85\x81"	// U+f141
#define ICON_FA_ELLIPSIS_H_ALT "\xef\x8e\x9b"	// U+f39b
#define ICON_FA_ELLIPSIS_V "\xef\x85\x82"	// U+f142
#define ICON_FA_ELLIPSIS_V_ALT "\xef\x8e\x9c"	// U+f39c
#define ICON_FA_EMPTY_SET "\xef\x99\x96"	// U+f656
#define ICON_FA_ENGINE_WARNING "\xef\x97\xb2"	// U+f5f2
#define ICON_FA_ENVELOPE "\xef\x83\xa0"	// U+f0e0
#define ICON_FA_ENVELOPE_OPEN "\xef\x8a\xb6"	// U+f2b6
#define ICON_FA_ENVELOPE_OPEN_DOLLAR "\xef\x99\x97"	// U+f657
#define ICON_FA_ENVELOPE_OPEN_TEXT "\xef\x99\x98"	// U+f658
#define ICON_FA_ENVELOPE_SQUARE "\xef\x86\x99"	// U+f199
#define ICON_FA_EQUALS "\xef\x94\xac"	// U+f52c
#define ICON_FA_ERASER "\xef\x84\xad"	// U+f12d
#define ICON_FA_ETHERNET "\xef\x9e\x96"	// U+f796
#define ICON_FA_EURO_SIGN "\xef\x85\x93"	// U+f153
#define ICON_FA_EXCHANGE "\xef\x83\xac"	// U+f0ec
#define ICON_FA_EXCHANGE_ALT "\xef\x8d\xa2"	// U+f362
#define ICON_FA_EXCLAMATION "\xef\x84\xaa"	// U+f12a
#define ICON_FA_EXCLAMATION_CIRCLE "\xef\x81\xaa"	// U+f06a
#define ICON_FA_EXCLAMATION_SQUARE "\xef\x8c\xa1"	// U+f321
#define ICON_FA_EXCLAMATION_TRIANGLE "\xef\x81\xb1"	// U+f071
#define ICON_FA_EXPAND "\xef\x81\xa5"	// U+f065
#define ICON_FA_EXPAND_ALT "\xef\x90\xa4"	// U+f424
#define ICON_FA_EXPAND_ARROWS "\xef\x8c\x9d"	// U+f31d
#define ICON_FA_EXPAND_ARROWS_ALT "\xef\x8c\x9e"	// U+f31e
#define ICON_FA_EXPAND_WIDE "\xef\x8c\xa0"	// U+f320
#define ICON_FA_EXTERNAL_LINK "\xef\x82\x8e"	// U+f08e
#define ICON_FA_EXTERNAL_LINK_ALT "\xef\x8d\x9d"	// U+f35d
#define ICON_FA_EXTERNAL_LINK_SQUARE "\xef\x85\x8c"	// U+f14c
#define ICON_FA_EXTERNAL_LINK_SQUARE_ALT "\xef\x8d\xa0"	// U+f360
#define ICON_FA_EYE "\xef\x81\xae"	// U+f06e
#define ICON_FA_EYE_DROPPER "\xef\x87\xbb"	// U+f1fb
#define ICON_FA_EYE_EVIL "\xef\x9b\x9b"	// U+f6db
#define ICON_FA_EYE_SLASH "\xef\x81\xb0"	// U+f070
#define ICON_FA_FAN "\xef\xa1\xa3"	// U+f863
#define ICON_FA_FAN_TABLE "\xef\xa4\x84"	// U+f904
#define ICON_FA_FARM "\xef\xa1\xa4"	// U+f864
#define ICON_FA_FAST_BACKWARD "\xef\x81\x89"	// U+f049
#define ICON_FA_FAST_FORWARD "\xef\x81\x90"	// U+f050
#define ICON_FA_FAUCET "\xef\xa4\x85"	// U+f905
#define ICON_FA_FAUCET_DRIP "\xef\xa4\x86"	// U+f906
#define ICON_FA_FAX "\xef\x86\xac"	// U+f1ac
#define ICON_FA_FEATHER "\xef\x94\xad"	// U+f52d
#define ICON_FA_FEATHER_ALT "\xef\x95\xab"	// U+f56b
#define ICON_FA_FEMALE "\xef\x86\x82"	// U+f182
#define ICON_FA_FIELD_HOCKEY "\xef\x91\x8c"	// U+f44c
#define ICON_FA_FIGHTER_JET "\xef\x83\xbb"	// U+f0fb
#define ICON_FA_FILE "\xef\x85\x9b"	// U+f15b
#define ICON_FA_FILE_ALT "\xef\x85\x9c"	// U+f15c
#define ICON_FA_FILE_ARCHIVE "\xef\x87\x86"	// U+f1c6
#define ICON_FA_FILE_AUDIO "\xef\x87\x87"	// U+f1c7
#define ICON_FA_FILE_CERTIFICATE "\xef\x97\xb3"	// U+f5f3
#define ICON_FA_FILE_CHART_LINE "\xef\x99\x99"	// U+f659
#define ICON_FA_FILE_CHART_PIE "\xef\x99\x9a"	// U+f65a
#define ICON_FA_FILE_CHECK "\xef\x8c\x96"	// U+f316
#define ICON_FA_FILE_CODE "\xef\x87\x89"	// U+f1c9
#define ICON_FA_FILE_CONTRACT "\xef\x95\xac"	// U+f56c
#define ICON_FA_FILE_CSV "\xef\x9b\x9d"	// U+f6dd
#define ICON_FA_FILE_DOWNLOAD "\xef\x95\xad"	// U+f56d
#define ICON_FA_FILE_EDIT "\xef\x8c\x9c"	// U+f31c
#define ICON_FA_FILE_EXCEL "\xef\x87\x83"	// U+f1c3
#define ICON_FA_FILE_EXCLAMATION "\xef\x8c\x9a"	// U+f31a
#define ICON_FA_FILE_EXPORT "\xef\x95\xae"	// U+f56e
#define ICON_FA_FILE_IMAGE "\xef\x87\x85"	// U+f1c5
#define ICON_FA_FILE_IMPORT "\xef\x95\xaf"	// U+f56f
#define ICON_FA_FILE_INVOICE "\xef\x95\xb0"	// U+f570
#define ICON_FA_FILE_INVOICE_DOLLAR "\xef\x95\xb1"	// U+f571
#define ICON_FA_FILE_MEDICAL "\xef\x91\xb7"	// U+f477
#define ICON_FA_FILE_MEDICAL_ALT "\xef\x91\xb8"	// U+f478
#define ICON_FA_FILE_MINUS "\xef\x8c\x98"	// U+f318
#define ICON_FA_FILE_MUSIC "\xef\xa2\xb6"	// U+f8b6
#define ICON_FA_FILE_PDF "\xef\x87\x81"	// U+f1c1
#define ICON_FA_FILE_PLUS "\xef\x8c\x99"	// U+f319
#define ICON_FA_FILE_POWERPOINT "\xef\x87\x84"	// U+f1c4
#define ICON_FA_FILE_PRESCRIPTION "\xef\x95\xb2"	// U+f572
#define ICON_FA_FILE_SEARCH "\xef\xa1\xa5"	// U+f865
#define ICON_FA_FILE_SIGNATURE "\xef\x95\xb3"	// U+f573
#define ICON_FA_FILE_SPREADSHEET "\xef\x99\x9b"	// U+f65b
#define ICON_FA_FILE_TIMES "\xef\x8c\x97"	// U+f317
#define ICON_FA_FILE_UPLOAD "\xef\x95\xb4"	// U+f574
#define ICON_FA_FILE_USER "\xef\x99\x9c"	// U+f65c
#define ICON_FA_FILE_VIDEO "\xef\x87\x88"	// U+f1c8
#define ICON_FA_FILE_WORD "\xef\x87\x82"	// U+f1c2
#define ICON_FA_FILES_MEDICAL "\xef\x9f\xbd"	// U+f7fd
#define ICON_FA_FILL "\xef\x95\xb5"	// U+f575
#define ICON_FA_FILL_DRIP "\xef\x95\xb6"	// U+f576
#define ICON_FA_FILM "\xef\x80\x88"	// U+f008
#define ICON_FA_FILM_ALT "\xef\x8e\xa0"	// U+f3a0
#define ICON_FA_FILM_CANISTER "\xef\xa2\xb7"	// U+f8b7
#define ICON_FA_FILTER "\xef\x82\xb0"	// U+f0b0
#define ICON_FA_FINGERPRINT "\xef\x95\xb7"	// U+f577
#define ICON_FA_FIRE "\xef\x81\xad"	// U+f06d
#define ICON_FA_FIRE_ALT "\xef\x9f\xa4"	// U+f7e4
#define ICON_FA_FIRE_EXTINGUISHER "\xef\x84\xb4"	// U+f134
#define ICON_FA_FIRE_SMOKE "\xef\x9d\x8b"	// U+f74b
#define ICON_FA_FIREPLACE "\xef\x9e\x9a"	// U+f79a
#define ICON_FA_FIRST_AID "\xef\x91\xb9"	// U+f479
#define ICON_FA_FISH "\xef\x95\xb8"	// U+f578
#define ICON_FA_FISH_COOKED "\xef\x9f\xbe"	// U+f7fe
#define ICON_FA_FIST_RAISED "\xef\x9b\x9e"	// U+f6de
#define ICON_FA_FLAG "\xef\x80\xa4"	// U+f024
#define ICON_FA_FLAG_ALT "\xef\x9d\x8c"	// U+f74c
#define ICON_FA_FLAG_CHECKERED "\xef\x84\x9e"	// U+f11e
#define ICON_FA_FLAG_USA "\xef\x9d\x8d"	// U+f74d
#define ICON_FA_FLAME "\xef\x9b\x9f"	// U+f6df
#define ICON_FA_FLASHLIGHT "\xef\xa2\xb8"	// U+f8b8
#define ICON_FA_FLASK "\xef\x83\x83"	// U+f0c3
#define ICON_FA_FLASK_POISON "\xef\x9b\xa0"	// U+f6e0
#define ICON_FA_FLASK_POTION "\xef\x9b\xa1"	// U+f6e1
#define ICON_FA_FLOWER "\xef\x9f\xbf"	// U+f7ff
#define ICON_FA_FLOWER_DAFFODIL "\xef\xa0\x80"	// U+f800
#define ICON_FA_FLOWER_TULIP "\xef\xa0\x81"	// U+f801
#define ICON_FA_FLUSHED "\xef\x95\xb9"	// U+f579
#define ICON_FA_FLUTE "\xef\xa2\xb9"	// U+f8b9
#define ICON_FA_FLUX_CAPACITOR "\xef\xa2\xba"	// U+f8ba
#define ICON_FA_FOG "\xef\x9d\x8e"	// U+f74e
#define ICON_FA_FOLDER "\xef\x81\xbb"	// U+f07b
#define ICON_FA_FOLDER_MINUS "\xef\x99\x9d"	// U+f65d
#define ICON_FA_FOLDER_OPEN "\xef\x81\xbc"	// U+f07c
#define ICON_FA_FOLDER_PLUS "\xef\x99\x9e"	// U+f65e
#define ICON_FA_FOLDER_TIMES "\xef\x99\x9f"	// U+f65f
#define ICON_FA_FOLDER_TREE "\xef\xa0\x82"	// U+f802
#define ICON_FA_FOLDERS "\xef\x99\xa0"	// U+f660
#define ICON_FA_FONT "\xef\x80\xb1"	// U+f031
#define ICON_FA_FONT_AWESOME_LOGO_FULL "\xef\x93\xa6"	// U+f4e6
#define ICON_FA_FONT_CASE "\xef\xa1\xa6"	// U+f866
#define ICON_FA_FOOTBALL_BALL "\xef\x91\x8e"	// U+f44e
#define ICON_FA_FOOTBALL_HELMET "\xef\x91\x8f"	// U+f44f
#define ICON_FA_FORKLIFT "\xef\x91\xba"	// U+f47a
#define ICON_FA_FORWARD "\xef\x81\x8e"	// U+f04e
#define ICON_FA_FRAGILE "\xef\x92\xbb"	// U+f4bb
#define ICON_FA_FRENCH_FRIES "\xef\xa0\x83"	// U+f803
#define ICON_FA_FROG "\xef\x94\xae"	// U+f52e
#define ICON_FA_FROSTY_HEAD "\xef\x9e\x9b"	// U+f79b
#define ICON_FA_FROWN "\xef\x84\x99"	// U+f119
#define ICON_FA_FROWN_OPEN "\xef\x95\xba"	// U+f57a
#define ICON_FA_FUNCTION "\xef\x99\xa1"	// U+f661
#define ICON_FA_FUNNEL_DOLLAR "\xef\x99\xa2"	// U+f662
#define ICON_FA_FUTBOL "\xef\x87\xa3"	// U+f1e3
#define ICON_FA_GALAXY "\xef\xa4\x88"	// U+f908
#define ICON_FA_GAME_BOARD "\xef\xa1\xa7"	// U+f867
#define ICON_FA_GAME_BOARD_ALT "\xef\xa1\xa8"	// U+f868
#define ICON_FA_GAME_CONSOLE_HANDHELD "\xef\xa2\xbb"	// U+f8bb
#define ICON_FA_GAMEPAD "\xef\x84\x9b"	// U+f11b
#define ICON_FA_GAMEPAD_ALT "\xef\xa2\xbc"	// U+f8bc
#define ICON_FA_GARAGE "\xef\xa4\x89"	// U+f909
#define ICON_FA_GARAGE_CAR "\xef\xa4\x8a"	// U+f90a
#define ICON_FA_GARAGE_OPEN "\xef\xa4\x8b"	// U+f90b
#define ICON_FA_GAS_PUMP "\xef\x94\xaf"	// U+f52f
#define ICON_FA_GAS_PUMP_SLASH "\xef\x97\xb4"	// U+f5f4
#define ICON_FA_GAVEL "\xef\x83\xa3"	// U+f0e3
#define ICON_FA_GEM "\xef\x8e\xa5"	// U+f3a5
#define ICON_FA_GENDERLESS "\xef\x88\xad"	// U+f22d
#define ICON_FA_GHOST "\xef\x9b\xa2"	// U+f6e2
#define ICON_FA_GIFT "\xef\x81\xab"	// U+f06b
#define ICON_FA_GIFT_CARD "\xef\x99\xa3"	// U+f663
#define ICON_FA_GIFTS "\xef\x9e\x9c"	// U+f79c
#define ICON_FA_GINGERBREAD_MAN "\xef\x9e\x9d"	// U+f79d
#define ICON_FA_GLASS "\xef\xa0\x84"	// U+f804
#define ICON_FA_GLASS_CHAMPAGNE "\xef\x9e\x9e"	// U+f79e
#define ICON_FA_GLASS_CHEERS "\xef\x9e\x9f"	// U+f79f
#define ICON_FA_GLASS_CITRUS "\xef\xa1\xa9"	// U+f869
#define ICON_FA_GLASS_MARTINI "\xef\x80\x80"	// U+f000
#define ICON_FA_GLASS_MARTINI_ALT "\xef\x95\xbb"	// U+f57b
#define ICON_FA_GLASS_WHISKEY "\xef\x9e\xa0"	// U+f7a0
#define ICON_FA_GLASS_WHISKEY_ROCKS "\xef\x9e\xa1"	// U+f7a1
#define ICON_FA_GLASSES "\xef\x94\xb0"	// U+f530
#define ICON_FA_GLASSES_ALT "\xef\x97\xb5"	// U+f5f5
#define ICON_FA_GLOBE "\xef\x82\xac"	// U+f0ac
#define ICON_FA_GLOBE_AFRICA "\xef\x95\xbc"	// U+f57c
#define ICON_FA_GLOBE_AMERICAS "\xef\x95\xbd"	// U+f57d
#define ICON_FA_GLOBE_ASIA "\xef\x95\xbe"	// U+f57e
#define ICON_FA_GLOBE_EUROPE "\xef\x9e\xa2"	// U+f7a2
#define ICON_FA_GLOBE_SNOW "\xef\x9e\xa3"	// U+f7a3
#define ICON_FA_GLOBE_STAND "\xef\x97\xb6"	// U+f5f6
#define ICON_FA_GOLF_BALL "\xef\x91\x90"	// U+f450
#define ICON_FA_GOLF_CLUB "\xef\x91\x91"	// U+f451
#define ICON_FA_GOPURAM "\xef\x99\xa4"	// U+f664
#define ICON_FA_GRADUATION_CAP "\xef\x86\x9d"	// U+f19d
#define ICON_FA_GRAMOPHONE "\xef\xa2\xbd"	// U+f8bd
#define ICON_FA_GREATER_THAN "\xef\x94\xb1"	// U+f531
#define ICON_FA_GREATER_THAN_EQUAL "\xef\x94\xb2"	// U+f532
#define ICON_FA_GRIMACE "\xef\x95\xbf"	// U+f57f
#define ICON_FA_GRIN "\xef\x96\x80"	// U+f580
#define ICON_FA_GRIN_ALT "\xef\x96\x81"	// U+f581
#define ICON_FA_GRIN_BEAM "\xef\x96\x82"	// U+f582
#define ICON_FA_GRIN_BEAM_SWEAT "\xef\x96\x83"	// U+f583
#define ICON_FA_GRIN_HEARTS "\xef\x96\x84"	// U+f584
#define ICON_FA_GRIN_SQUINT "\xef\x96\x85"	// U+f585
#define ICON_FA_GRIN_SQUINT_TEARS "\xef\x96\x86"	// U+f586
#define ICON_FA_GRIN_STARS "\xef\x96\x87"	// U+f587
#define ICON_FA_GRIN_TEARS "\xef\x96\x88"	// U+f588
#define ICON_FA_GRIN_TONGUE "\xef\x96\x89"	// U+f589
#define ICON_FA_GRIN_TONGUE_SQUINT "\xef\x96\x8a"	// U+f58a
#define ICON_FA_GRIN_TONGUE_WINK "\xef\x96\x8b"	// U+f58b
#define ICON_FA_GRIN_WINK "\xef\x96\x8c"	// U+f58c
#define ICON_FA_GRIP_HORIZONTAL "\xef\x96\x8d"	// U+f58d
#define ICON_FA_GRIP_LINES "\xef\x9e\xa4"	// U+f7a4
#define ICON_FA_GRIP_LINES_VERTICAL "\xef\x9e\xa5"	// U+f7a5
#define ICON_FA_GRIP_VERTICAL "\xef\x96\x8e"	// U+f58e
#define ICON_FA_GUITAR "\xef\x9e\xa6"	// U+f7a6
#define ICON_FA_GUITAR_ELECTRIC "\xef\xa2\xbe"	// U+f8be
#define ICON_FA_GUITARS "\xef\xa2\xbf"	// U+f8bf
#define ICON_FA_H_SQUARE "\xef\x83\xbd"	// U+f0fd
#define ICON_FA_H1 "\xef\x8c\x93"	// U+f313
#define ICON_FA_H2 "\xef\x8c\x94"	// U+f314
#define ICON_FA_H3 "\xef\x8c\x95"	// U+f315
#define ICON_FA_H4 "\xef\xa1\xaa"	// U+f86a
#define ICON_FA_HAMBURGER "\xef\xa0\x85"	// U+f805
#define ICON_FA_HAMMER "\xef\x9b\xa3"	// U+f6e3
#define ICON_FA_HAMMER_WAR "\xef\x9b\xa4"	// U+f6e4
#define ICON_FA_HAMSA "\xef\x99\xa5"	// U+f665
#define ICON_FA_HAND_HEART "\xef\x92\xbc"	// U+f4bc
#define ICON_FA_HAND_HOLDING "\xef\x92\xbd"	// U+f4bd
#define ICON_FA_HAND_HOLDING_BOX "\xef\x91\xbb"	// U+f47b
#define ICON_FA_HAND_HOLDING_HEART "\xef\x92\xbe"	// U+f4be
#define ICON_FA_HAND_HOLDING_MAGIC "\xef\x9b\xa5"	// U+f6e5
#define ICON_FA_HAND_HOLDING_SEEDLING "\xef\x92\xbf"	// U+f4bf
#define ICON_FA_HAND_HOLDING_USD "\xef\x93\x80"	// U+f4c0
#define ICON_FA_HAND_HOLDING_WATER "\xef\x93\x81"	// U+f4c1
#define ICON_FA_HAND_LIZARD "\xef\x89\x98"	// U+f258
#define ICON_FA_HAND_MIDDLE_FINGER "\xef\xa0\x86"	// U+f806
#define ICON_FA_HAND_PAPER "\xef\x89\x96"	// U+f256
#define ICON_FA_HAND_PEACE "\xef\x89\x9b"	// U+f25b
#define ICON_FA_HAND_POINT_DOWN "\xef\x82\xa7"	// U+f0a7
#define ICON_FA_HAND_POINT_LEFT "\xef\x82\xa5"	// U+f0a5
#define ICON_FA_HAND_POINT_RIGHT "\xef\x82\xa4"	// U+f0a4
#define ICON_FA_HAND_POINT_UP "\xef\x82\xa6"	// U+f0a6
#define ICON_FA_HAND_POINTER "\xef\x89\x9a"	// U+f25a
#define ICON_FA_HAND_RECEIVING "\xef\x91\xbc"	// U+f47c
#define ICON_FA_HAND_ROCK "\xef\x89\x95"	// U+f255
#define ICON_FA_HAND_SCISSORS "\xef\x89\x97"	// U+f257
#define ICON_FA_HAND_SPOCK "\xef\x89\x99"	// U+f259
#define ICON_FA_HANDS "\xef\x93\x82"	// U+f4c2
#define ICON_FA_HANDS_HEART "\xef\x93\x83"	// U+f4c3
#define ICON_FA_HANDS_HELPING "\xef\x93\x84"	// U+f4c4
#define ICON_FA_HANDS_USD "\xef\x93\x85"	// U+f4c5
#define ICON_FA_HANDSHAKE "\xef\x8a\xb5"	// U+f2b5
#define ICON_FA_HANDSHAKE_ALT "\xef\x93\x86"	// U+f4c6
#define ICON_FA_HANUKIAH "\xef\x9b\xa6"	// U+f6e6
#define ICON_FA_HARD_HAT "\xef\xa0\x87"	// U+f807
#define ICON_FA_HASHTAG "\xef\x8a\x92"	// U+f292
#define ICON_FA_HAT_CHEF "\xef\xa1\xab"	// U+f86b
#define ICON_FA_HAT_COWBOY "\xef\xa3\x80"	// U+f8c0
#define ICON_FA_HAT_COWBOY_SIDE "\xef\xa3\x81"	// U+f8c1
#define ICON_FA_HAT_SANTA "\xef\x9e\xa7"	// U+f7a7
#define ICON_FA_HAT_WINTER "\xef\x9e\xa8"	// U+f7a8
#define ICON_FA_HAT_WITCH "\xef\x9b\xa7"	// U+f6e7
#define ICON_FA_HAT_WIZARD "\xef\x9b\xa8"	// U+f6e8
#define ICON_FA_HDD "\xef\x82\xa0"	// U+f0a0
#define ICON_FA_HEAD_SIDE "\xef\x9b\xa9"	// U+f6e9
#define ICON_FA_HEAD_SIDE_BRAIN "\xef\xa0\x88"	// U+f808
#define ICON_FA_HEAD_SIDE_HEADPHONES "\xef\xa3\x82"	// U+f8c2
#define ICON_FA_HEAD_SIDE_MEDICAL "\xef\xa0\x89"	// U+f809
#define ICON_FA_HEAD_VR "\xef\x9b\xaa"	// U+f6ea
#define ICON_FA_HEADING "\xef\x87\x9c"	// U+f1dc
#define ICON_FA_HEADPHONES "\xef\x80\xa5"	// U+f025
#define ICON_FA_HEADPHONES_ALT "\xef\x96\x8f"	// U+f58f
#define ICON_FA_HEADSET "\xef\x96\x90"	// U+f590
#define ICON_FA_HEART "\xef\x80\x84"	// U+f004
#define ICON_FA_HEART_BROKEN "\xef\x9e\xa9"	// U+f7a9
#define ICON_FA_HEART_CIRCLE "\xef\x93\x87"	// U+f4c7
#define ICON_FA_HEART_RATE "\xef\x97\xb8"	// U+f5f8
#define ICON_FA_HEART_SQUARE "\xef\x93\x88"	// U+f4c8
#define ICON_FA_HEARTBEAT "\xef\x88\x9e"	// U+f21e
#define ICON_FA_HEAT "\xef\xa4\x8c"	// U+f90c
#define ICON_FA_HELICOPTER "\xef\x94\xb3"	// U+f533
#define ICON_FA_HELMET_BATTLE "\xef\x9b\xab"	// U+f6eb
#define ICON_FA_HEXAGON "\xef\x8c\x92"	// U+f312
#define ICON_FA_HIGHLIGHTER "\xef\x96\x91"	// U+f591
#define ICON_FA_HIKING "\xef\x9b\xac"	// U+f6ec
#define ICON_FA_HIPPO "\xef\x9b\xad"	// U+f6ed
#define ICON_FA_HISTORY "\xef\x87\x9a"	// U+f1da
#define ICON_FA_HOCKEY_MASK "\xef\x9b\xae"	// U+f6ee
#define ICON_FA_HOCKEY_PUCK "\xef\x91\x93"	// U+f453
#define ICON_FA_HOCKEY_STICKS "\xef\x91\x94"	// U+f454
#define ICON_FA_HOLLY_BERRY "\xef\x9e\xaa"	// U+f7aa
#define ICON_FA_HOME "\xef\x80\x95"	// U+f015
#define ICON_FA_HOME_ALT "\xef\xa0\x8a"	// U+f80a
#define ICON_FA_HOME_HEART "\xef\x93\x89"	// U+f4c9
#define ICON_FA_HOME_LG "\xef\xa0\x8b"	// U+f80b
#define ICON_FA_HOME_LG_ALT "\xef\xa0\x8c"	// U+f80c
#define ICON_FA_HOOD_CLOAK "\xef\x9b\xaf"	// U+f6ef
#define ICON_FA_HORIZONTAL_RULE "\xef\xa1\xac"	// U+f86c
#define ICON_FA_HORSE "\xef\x9b\xb0"	// U+f6f0
#define ICON_FA_HORSE_HEAD "\xef\x9e\xab"	// U+f7ab
#define ICON_FA_HORSE_SADDLE "\xef\xa3\x83"	// U+f8c3
#define ICON_FA_HOSPITAL "\xef\x83\xb8"	// U+f0f8
#define ICON_FA_HOSPITAL_ALT "\xef\x91\xbd"	// U+f47d
#define ICON_FA_HOSPITAL_SYMBOL "\xef\x91\xbe"	// U+f47e
#define ICON_FA_HOSPITAL_USER "\xef\xa0\x8d"	// U+f80d
#define ICON_FA_HOSPITALS "\xef\xa0\x8e"	// U+f80e
#define ICON_FA_HOT_TUB "\xef\x96\x93"	// U+f593
#define ICON_FA_HOTDOG "\xef\xa0\x8f"	// U+f80f
#define ICON_FA_HOTEL "\xef\x96\x94"	// U+f594
#define ICON_FA_HOURGLASS "\xef\x89\x94"	// U+f254
#define ICON_FA_HOURGLASS_END "\xef\x89\x93"	// U+f253
#define ICON_FA_HOURGLASS_HALF "\xef\x89\x92"	// U+f252
#define ICON_FA_HOURGLASS_START "\xef\x89\x91"	// U+f251
#define ICON_FA_HOUSE "\xef\xa4\x8d"	// U+f90d
#define ICON_FA_HOUSE_DAMAGE "\xef\x9b\xb1"	// U+f6f1
#define ICON_FA_HOUSE_DAY "\xef\xa4\x8e"	// U+f90e
#define ICON_FA_HOUSE_FLOOD "\xef\x9d\x8f"	// U+f74f
#define ICON_FA_HOUSE_LEAVE "\xef\xa4\x8f"	// U+f90f
#define ICON_FA_HOUSE_NIGHT "\xef\xa4\x90"	// U+f910
#define ICON_FA_HOUSE_RETURN "\xef\xa4\x91"	// U+f911
#define ICON_FA_HOUSE_SIGNAL "\xef\xa4\x92"	// U+f912
#define ICON_FA_HRYVNIA "\xef\x9b\xb2"	// U+f6f2
#define ICON_FA_HUMIDITY "\xef\x9d\x90"	// U+f750
#define ICON_FA_HURRICANE "\xef\x9d\x91"	// U+f751
#define ICON_FA_I_CURSOR "\xef\x89\x86"	// U+f246
#define ICON_FA_ICE_CREAM "\xef\xa0\x90"	// U+f810
#define ICON_FA_ICE_SKATE "\xef\x9e\xac"	// U+f7ac
#define ICON_FA_ICICLES "\xef\x9e\xad"	// U+f7ad
#define ICON_FA_ICONS "\xef\xa1\xad"	// U+f86d
#define ICON_FA_ICONS_ALT "\xef\xa1\xae"	// U+f86e
#define ICON_FA_ID_BADGE "\xef\x8b\x81"	// U+f2c1
#define ICON_FA_ID_CARD "\xef\x8b\x82"	// U+f2c2
#define ICON_FA_ID_CARD_ALT "\xef\x91\xbf"	// U+f47f
#define ICON_FA_IGLOO "\xef\x9e\xae"	// U+f7ae
#define ICON_FA_IMAGE "\xef\x80\xbe"	// U+f03e
#define ICON_FA_IMAGE_POLAROID "\xef\xa3\x84"	// U+f8c4
#define ICON_FA_IMAGES "\xef\x8c\x82"	// U+f302
#define ICON_FA_INBOX "\xef\x80\x9c"	// U+f01c
#define ICON_FA_INBOX_IN "\xef\x8c\x90"	// U+f310
#define ICON_FA_INBOX_OUT "\xef\x8c\x91"	// U+f311
#define ICON_FA_INDENT "\xef\x80\xbc"	// U+f03c
#define ICON_FA_INDUSTRY "\xef\x89\xb5"	// U+f275
#define ICON_FA_INDUSTRY_ALT "\xef\x8e\xb3"	// U+f3b3
#define ICON_FA_INFINITY "\xef\x94\xb4"	// U+f534
#define ICON_FA_INFO "\xef\x84\xa9"	// U+f129
#define ICON_FA_INFO_CIRCLE "\xef\x81\x9a"	// U+f05a
#define ICON_FA_INFO_SQUARE "\xef\x8c\x8f"	// U+f30f
#define ICON_FA_INHALER "\xef\x97\xb9"	// U+f5f9
#define ICON_FA_INTEGRAL "\xef\x99\xa7"	// U+f667
#define ICON_FA_INTERSECTION "\xef\x99\xa8"	// U+f668
#define ICON_FA_INVENTORY "\xef\x92\x80"	// U+f480
#define ICON_FA_ISLAND_TROPICAL "\xef\xa0\x91"	// U+f811
#define ICON_FA_ITALIC "\xef\x80\xb3"	// U+f033
#define ICON_FA_JACK_O_LANTERN "\xef\x8c\x8e"	// U+f30e
#define ICON_FA_JEDI "\xef\x99\xa9"	// U+f669
#define ICON_FA_JOINT "\xef\x96\x95"	// U+f595
#define ICON_FA_JOURNAL_WHILLS "\xef\x99\xaa"	// U+f66a
#define ICON_FA_JOYSTICK "\xef\xa3\x85"	// U+f8c5
#define ICON_FA_JUG "\xef\xa3\x86"	// U+f8c6
#define ICON_FA_KAABA "\xef\x99\xab"	// U+f66b
#define ICON_FA_KAZOO "\xef\xa3\x87"	// U+f8c7
#define ICON_FA_KERNING "\xef\xa1\xaf"	// U+f86f
#define ICON_FA_KEY "\xef\x82\x84"	// U+f084
#define ICON_FA_KEY_SKELETON "\xef\x9b\xb3"	// U+f6f3
#define ICON_FA_KEYBOARD "\xef\x84\x9c"	// U+f11c
#define ICON_FA_KEYNOTE "\xef\x99\xac"	// U+f66c
#define ICON_FA_KHANDA "\xef\x99\xad"	// U+f66d
#define ICON_FA_KIDNEYS "\xef\x97\xbb"	// U+f5fb
#define ICON_FA_KISS "\xef\x96\x96"	// U+f596
#define ICON_FA_KISS_BEAM "\xef\x96\x97"	// U+f597
#define ICON_FA_KISS_WINK_HEART "\xef\x96\x98"	// U+f598
#define ICON_FA_KITE "\xef\x9b\xb4"	// U+f6f4
#define ICON_FA_KIWI_BIRD "\xef\x94\xb5"	// U+f535
#define ICON_FA_KNIFE_KITCHEN "\xef\x9b\xb5"	// U+f6f5
#define ICON_FA_LAMBDA "\xef\x99\xae"	// U+f66e
#define ICON_FA_LAMP "\xef\x93\x8a"	// U+f4ca
#define ICON_FA_LAMP_DESK "\xef\xa4\x94"	// U+f914
#define ICON_FA_LAMP_FLOOR "\xef\xa4\x95"	// U+f915
#define ICON_FA_LANDMARK "\xef\x99\xaf"	// U+f66f
#define ICON_FA_LANDMARK_ALT "\xef\x9d\x92"	// U+f752
#define ICON_FA_LANGUAGE "\xef\x86\xab"	// U+f1ab
#define ICON_FA_LAPTOP "\xef\x84\x89"	// U+f109
#define ICON_FA_LAPTOP_CODE "\xef\x97\xbc"	// U+f5fc
#define ICON_FA_LAPTOP_MEDICAL "\xef\xa0\x92"	// U+f812
#define ICON_FA_LASSO "\xef\xa3\x88"	// U+f8c8
#define ICON_FA_LAUGH "\xef\x96\x99"	// U+f599
#define ICON_FA_LAUGH_BEAM "\xef\x96\x9a"	// U+f59a
#define ICON_FA_LAUGH_SQUINT "\xef\x96\x9b"	// U+f59b
#define ICON_FA_LAUGH_WINK "\xef\x96\x9c"	// U+f59c
#define ICON_FA_LAYER_GROUP "\xef\x97\xbd"	// U+f5fd
#define ICON_FA_LAYER_MINUS "\xef\x97\xbe"	// U+f5fe
#define ICON_FA_LAYER_PLUS "\xef\x97\xbf"	// U+f5ff
#define ICON_FA_LEAF "\xef\x81\xac"	// U+f06c
#define ICON_FA_LEAF_HEART "\xef\x93\x8b"	// U+f4cb
#define ICON_FA_LEAF_MAPLE "\xef\x9b\xb6"	// U+f6f6
#define ICON_FA_LEAF_OAK "\xef\x9b\xb7"	// U+f6f7
#define ICON_FA_LEMON "\xef\x82\x94"	// U+f094
#define ICON_FA_LESS_THAN "\xef\x94\xb6"	// U+f536
#define ICON_FA_LESS_THAN_EQUAL "\xef\x94\xb7"	// U+f537
#define ICON_FA_LEVEL_DOWN "\xef\x85\x89"	// U+f149
#define ICON_FA_LEVEL_DOWN_ALT "\xef\x8e\xbe"	// U+f3be
#define ICON_FA_LEVEL_UP "\xef\x85\x88"	// U+f148
#define ICON_FA_LEVEL_UP_ALT "\xef\x8e\xbf"	// U+f3bf
#define ICON_FA_LIFE_RING "\xef\x87\x8d"	// U+f1cd
#define ICON_FA_LIGHT_CEILING "\xef\xa4\x96"	// U+f916
#define ICON_FA_LIGHT_SWITCH "\xef\xa4\x97"	// U+f917
#define ICON_FA_LIGHT_SWITCH_OFF "\xef\xa4\x98"	// U+f918
#define ICON_FA_LIGHT_SWITCH_ON "\xef\xa4\x99"	// U+f919
#define ICON_FA_LIGHTBULB "\xef\x83\xab"	// U+f0eb
#define ICON_FA_LIGHTBULB_DOLLAR "\xef\x99\xb0"	// U+f670
#define ICON_FA_LIGHTBULB_EXCLAMATION "\xef\x99\xb1"	// U+f671
#define ICON_FA_LIGHTBULB_ON "\xef\x99\xb2"	// U+f672
#define ICON_FA_LIGHTBULB_SLASH "\xef\x99\xb3"	// U+f673
#define ICON_FA_LIGHTS_HOLIDAY "\xef\x9e\xb2"	// U+f7b2
#define ICON_FA_LINE_COLUMNS "\xef\xa1\xb0"	// U+f870
#define ICON_FA_LINE_HEIGHT "\xef\xa1\xb1"	// U+f871
#define ICON_FA_LINK "\xef\x83\x81"	// U+f0c1
#define ICON_FA_LIPS "\xef\x98\x80"	// U+f600
#define ICON_FA_LIRA_SIGN "\xef\x86\x95"	// U+f195
#define ICON_FA_LIST "\xef\x80\xba"	// U+f03a
#define ICON_FA_LIST_ALT "\xef\x80\xa2"	// U+f022
#define ICON_FA_LIST_MUSIC "\xef\xa3\x89"	// U+f8c9
#define ICON_FA_LIST_OL "\xef\x83\x8b"	// U+f0cb
#define ICON_FA_LIST_UL "\xef\x83\x8a"	// U+f0ca
#define ICON_FA_LOCATION "\xef\x98\x81"	// U+f601
#define ICON_FA_LOCATION_ARROW "\xef\x84\xa4"	// U+f124
#define ICON_FA_LOCATION_CIRCLE "\xef\x98\x82"	// U+f602
#define ICON_FA_LOCATION_SLASH "\xef\x98\x83"	// U+f603
#define ICON_FA_LOCK "\xef\x80\xa3"	// U+f023
#define ICON_FA_LOCK_ALT "\xef\x8c\x8d"	// U+f30d
#define ICON_FA_LOCK_OPEN "\xef\x8f\x81"	// U+f3c1
#define ICON_FA_LOCK_OPEN_ALT "\xef\x8f\x82"	// U+f3c2
#define ICON_FA_LONG_ARROW_ALT_DOWN "\xef\x8c\x89"	// U+f309
#define ICON_FA_LONG_ARROW_ALT_LEFT "\xef\x8c\x8a"	// U+f30a
#define ICON_FA_LONG_ARROW_ALT_RIGHT "\xef\x8c\x8b"	// U+f30b
#define ICON_FA_LONG_ARROW_ALT_UP "\xef\x8c\x8c"	// U+f30c
#define ICON_FA_LONG_ARROW_DOWN "\xef\x85\xb5"	// U+f175
#define ICON_FA_LONG_ARROW_LEFT "\xef\x85\xb7"	// U+f177
#define ICON_FA_LONG_ARROW_RIGHT "\xef\x85\xb8"	// U+f178
#define ICON_FA_LONG_ARROW_UP "\xef\x85\xb6"	// U+f176
#define ICON_FA_LOVESEAT "\xef\x93\x8c"	// U+f4cc
#define ICON_FA_LOW_VISION "\xef\x8a\xa8"	// U+f2a8
#define ICON_FA_LUCHADOR "\xef\x91\x95"	// U+f455
#define ICON_FA_LUGGAGE_CART "\xef\x96\x9d"	// U+f59d
#define ICON_FA_LUNGS "\xef\x98\x84"	// U+f604
#define ICON_FA_MACE "\xef\x9b\xb8"	// U+f6f8
#define ICON_FA_MAGIC "\xef\x83\x90"	// U+f0d0
#define ICON_FA_MAGNET "\xef\x81\xb6"	// U+f076
#define ICON_FA_MAIL_BULK "\xef\x99\xb4"	// U+f674
#define ICON_FA_MAILBOX "\xef\xa0\x93"	// U+f813
#define ICON_FA_MALE "\xef\x86\x83"	// U+f183
#define ICON_FA_MANDOLIN "\xef\x9b\xb9"	// U+f6f9
#define ICON_FA_MAP "\xef\x89\xb9"	// U+f279
#define ICON_FA_MAP_MARKED "\xef\x96\x9f"	// U+f59f
#define ICON_FA_MAP_MARKED_ALT "\xef\x96\xa0"	// U+f5a0
#define ICON_FA_MAP_MARKER "\xef\x81\x81"	// U+f041
#define ICON_FA_MAP_MARKER_ALT "\xef\x8f\x85"	// U+f3c5
#define ICON_FA_MAP_MARKER_ALT_SLASH "\xef\x98\x85"	// U+f605
#define ICON_FA_MAP_MARKER_CHECK "\xef\x98\x86"	// U+f606
#define ICON_FA_MAP_MARKER_EDIT "\xef\x98\x87"	// U+f607
#define ICON_FA_MAP_MARKER_EXCLAMATION "\xef\x98\x88"	// U+f608
#define ICON_FA_MAP_MARKER_MINUS "\xef\x98\x89"	// U+f609
#define ICON_FA_MAP_MARKER_PLUS "\xef\x98\x8a"	// U+f60a
#define ICON_FA_MAP_MARKER_QUESTION "\xef\x98\x8b"	// U+f60b
#define ICON_FA_MAP_MARKER_SLASH "\xef\x98\x8c"	// U+f60c
#define ICON_FA_MAP_MARKER_SMILE "\xef\x98\x8d"	// U+f60d
#define ICON_FA_MAP_MARKER_TIMES "\xef\x98\x8e"	// U+f60e
#define ICON_FA_MAP_PIN "\xef\x89\xb6"	// U+f276
#define ICON_FA_MAP_SIGNS "\xef\x89\xb7"	// U+f277
#define ICON_FA_MARKER "\xef\x96\xa1"	// U+f5a1
#define ICON_FA_MARS "\xef\x88\xa2"	// U+f222
#define ICON_FA_MARS_DOUBLE "\xef\x88\xa7"	// U+f227
#define ICON_FA_MARS_STROKE "\xef\x88\xa9"	// U+f229
#define ICON_FA_MARS_STROKE_H "\xef\x88\xab"	// U+f22b
#define ICON_FA_MARS_STROKE_V "\xef\x88\xaa"	// U+f22a
#define ICON_FA_MASK "\xef\x9b\xba"	// U+f6fa
#define ICON_FA_MEAT "\xef\xa0\x94"	// U+f814
#define ICON_FA_MEDAL "\xef\x96\xa2"	// U+f5a2
#define ICON_FA_MEDKIT "\xef\x83\xba"	// U+f0fa
#define ICON_FA_MEGAPHONE "\xef\x99\xb5"	// U+f675
#define ICON_FA_MEH "\xef\x84\x9a"	// U+f11a
#define ICON_FA_MEH_BLANK "\xef\x96\xa4"	// U+f5a4
#define ICON_FA_MEH_ROLLING_EYES "\xef\x96\xa5"	// U+f5a5
#define ICON_FA_MEMORY "\xef\x94\xb8"	// U+f538
#define ICON_FA_MENORAH "\xef\x99\xb6"	// U+f676
#define ICON_FA_MERCURY "\xef\x88\xa3"	// U+f223
#define ICON_FA_METEOR "\xef\x9d\x93"	// U+f753
#define ICON_FA_MICROCHIP "\xef\x8b\x9b"	// U+f2db
#define ICON_FA_MICROPHONE "\xef\x84\xb0"	// U+f130
#define ICON_FA_MICROPHONE_ALT "\xef\x8f\x89"	// U+f3c9
#define ICON_FA_MICROPHONE_ALT_SLASH "\xef\x94\xb9"	// U+f539
#define ICON_FA_MICROPHONE_SLASH "\xef\x84\xb1"	// U+f131
#define ICON_FA_MICROPHONE_STAND "\xef\xa3\x8b"	// U+f8cb
#define ICON_FA_MICROSCOPE "\xef\x98\x90"	// U+f610
#define ICON_FA_MICROWAVE "\xef\xa4\x9b"	// U+f91b
#define ICON_FA_MIND_SHARE "\xef\x99\xb7"	// U+f677
#define ICON_FA_MINUS "\xef\x81\xa8"	// U+f068
#define ICON_FA_MINUS_CIRCLE "\xef\x81\x96"	// U+f056
#define ICON_FA_MINUS_HEXAGON "\xef\x8c\x87"	// U+f307
#define ICON_FA_MINUS_OCTAGON "\xef\x8c\x88"	// U+f308
#define ICON_FA_MINUS_SQUARE "\xef\x85\x86"	// U+f146
#define ICON_FA_MISTLETOE "\xef\x9e\xb4"	// U+f7b4
#define ICON_FA_MITTEN "\xef\x9e\xb5"	// U+f7b5
#define ICON_FA_MOBILE "\xef\x84\x8b"	// U+f10b
#define ICON_FA_MOBILE_ALT "\xef\x8f\x8d"	// U+f3cd
#define ICON_FA_MOBILE_ANDROID "\xef\x8f\x8e"	// U+f3ce
#define ICON_FA_MOBILE_ANDROID_ALT "\xef\x8f\x8f"	// U+f3cf
#define ICON_FA_MONEY_BILL "\xef\x83\x96"	// U+f0d6
#define ICON_FA_MONEY_BILL_ALT "\xef\x8f\x91"	// U+f3d1
#define ICON_FA_MONEY_BILL_WAVE "\xef\x94\xba"	// U+f53a
#define ICON_FA_MONEY_BILL_WAVE_ALT "\xef\x94\xbb"	// U+f53b
#define ICON_FA_MONEY_CHECK "\xef\x94\xbc"	// U+f53c
#define ICON_FA_MONEY_CHECK_ALT "\xef\x94\xbd"	// U+f53d
#define ICON_FA_MONEY_CHECK_EDIT "\xef\xa1\xb2"	// U+f872
#define ICON_FA_MONEY_CHECK_EDIT_ALT "\xef\xa1\xb3"	// U+f873
#define ICON_FA_MONITOR_HEART_RATE "\xef\x98\x91"	// U+f611
#define ICON_FA_MONKEY "\xef\x9b\xbb"	// U+f6fb
#define ICON_FA_MONUMENT "\xef\x96\xa6"	// U+f5a6
#define ICON_FA_MOON "\xef\x86\x86"	// U+f186
#define ICON_FA_MOON_CLOUD "\xef\x9d\x94"	// U+f754
#define ICON_FA_MOON_STARS "\xef\x9d\x95"	// U+f755
#define ICON_FA_MORTAR_PESTLE "\xef\x96\xa7"	// U+f5a7
#define ICON_FA_MOSQUE "\xef\x99\xb8"	// U+f678
#define ICON_FA_MOTORCYCLE "\xef\x88\x9c"	// U+f21c
#define ICON_FA_MOUNTAIN "\xef\x9b\xbc"	// U+f6fc
#define ICON_FA_MOUNTAINS "\xef\x9b\xbd"	// U+f6fd
#define ICON_FA_MOUSE "\xef\xa3\x8c"	// U+f8cc
#define ICON_FA_MOUSE_ALT "\xef\xa3\x8d"	// U+f8cd
#define ICON_FA_MOUSE_POINTER "\xef\x89\x85"	// U+f245
#define ICON_FA_MP3_PLAYER "\xef\xa3\x8e"	// U+f8ce
#define ICON_FA_MUG "\xef\xa1\xb4"	// U+f874
#define ICON_FA_MUG_HOT "\xef\x9e\xb6"	// U+f7b6
#define ICON_FA_MUG_MARSHMALLOWS "\xef\x9e\xb7"	// U+f7b7
#define ICON_FA_MUG_TEA "\xef\xa1\xb5"	// U+f875
#define ICON_FA_MUSIC "\xef\x80\x81"	// U+f001
#define ICON_FA_MUSIC_ALT "\xef\xa3\x8f"	// U+f8cf
#define ICON_FA_MUSIC_ALT_SLASH "\xef\xa3\x90"	// U+f8d0
#define ICON_FA_MUSIC_SLASH "\xef\xa3\x91"	// U+f8d1
#define ICON_FA_NARWHAL "\xef\x9b\xbe"	// U+f6fe
#define ICON_FA_NETWORK_WIRED "\xef\x9b\xbf"	// U+f6ff
#define ICON_FA_NEUTER "\xef\x88\xac"	// U+f22c
#define ICON_FA_NEWSPAPER "\xef\x87\xaa"	// U+f1ea
#define ICON_FA_NOT_EQUAL "\xef\x94\xbe"	// U+f53e
#define ICON_FA_NOTES_MEDICAL "\xef\x92\x81"	// U+f481
#define ICON_FA_OBJECT_GROUP "\xef\x89\x87"	// U+f247
#define ICON_FA_OBJECT_UNGROUP "\xef\x89\x88"	// U+f248
#define ICON_FA_OCTAGON "\xef\x8c\x86"	// U+f306
#define ICON_FA_OIL_CAN "\xef\x98\x93"	// U+f613
#define ICON_FA_OIL_TEMP "\xef\x98\x94"	// U+f614
#define ICON_FA_OM "\xef\x99\xb9"	// U+f679
#define ICON_FA_OMEGA "\xef\x99\xba"	// U+f67a
#define ICON_FA_ORNAMENT "\xef\x9e\xb8"	// U+f7b8
#define ICON_FA_OTTER "\xef\x9c\x80"	// U+f700
#define ICON_FA_OUTDENT "\xef\x80\xbb"	// U+f03b
#define ICON_FA_OUTLET "\xef\xa4\x9c"	// U+f91c
#define ICON_FA_OVEN "\xef\xa4\x9d"	// U+f91d
#define ICON_FA_OVERLINE "\xef\xa1\xb6"	// U+f876
#define ICON_FA_PAGE_BREAK "\xef\xa1\xb7"	// U+f877
#define ICON_FA_PAGER "\xef\xa0\x95"	// U+f815
#define ICON_FA_PAINT_BRUSH "\xef\x87\xbc"	// U+f1fc
#define ICON_FA_PAINT_BRUSH_ALT "\xef\x96\xa9"	// U+f5a9
#define ICON_FA_PAINT_ROLLER "\xef\x96\xaa"	// U+f5aa
#define ICON_FA_PALETTE "\xef\x94\xbf"	// U+f53f
#define ICON_FA_PALLET "\xef\x92\x82"	// U+f482
#define ICON_FA_PALLET_ALT "\xef\x92\x83"	// U+f483
#define ICON_FA_PAPER_PLANE "\xef\x87\x98"	// U+f1d8
#define ICON_FA_PAPERCLIP "\xef\x83\x86"	// U+f0c6
#define ICON_FA_PARACHUTE_BOX "\xef\x93\x8d"	// U+f4cd
#define ICON_FA_PARAGRAPH "\xef\x87\x9d"	// U+f1dd
#define ICON_FA_PARAGRAPH_RTL "\xef\xa1\xb8"	// U+f878
#define ICON_FA_PARKING "\xef\x95\x80"	// U+f540
#define ICON_FA_PARKING_CIRCLE "\xef\x98\x95"	// U+f615
#define ICON_FA_PARKING_CIRCLE_SLASH "\xef\x98\x96"	// U+f616
#define ICON_FA_PARKING_SLASH "\xef\x98\x97"	// U+f617
#define ICON_FA_PASSPORT "\xef\x96\xab"	// U+f5ab
#define ICON_FA_PASTAFARIANISM "\xef\x99\xbb"	// U+f67b
#define ICON_FA_PASTE "\xef\x83\xaa"	// U+f0ea
#define ICON_FA_PAUSE "\xef\x81\x8c"	// U+f04c
#define ICON_FA_PAUSE_CIRCLE "\xef\x8a\x8b"	// U+f28b
#define ICON_FA_PAW "\xef\x86\xb0"	// U+f1b0
#define ICON_FA_PAW_ALT "\xef\x9c\x81"	// U+f701
#define ICON_FA_PAW_CLAWS "\xef\x9c\x82"	// U+f702
#define ICON_FA_PEACE "\xef\x99\xbc"	// U+f67c
#define ICON_FA_PEGASUS "\xef\x9c\x83"	// U+f703
#define ICON_FA_PEN "\xef\x8c\x84"	// U+f304
#define ICON_FA_PEN_ALT "\xef\x8c\x85"	// U+f305
#define ICON_FA_PEN_FANCY "\xef\x96\xac"	// U+f5ac
#define ICON_FA_PEN_NIB "\xef\x96\xad"	// U+f5ad
#define ICON_FA_PEN_SQUARE "\xef\x85\x8b"	// U+f14b
#define ICON_FA_PENCIL "\xef\x81\x80"	// U+f040
#define ICON_FA_PENCIL_ALT "\xef\x8c\x83"	// U+f303
#define ICON_FA_PENCIL_PAINTBRUSH "\xef\x98\x98"	// U+f618
#define ICON_FA_PENCIL_RULER "\xef\x96\xae"	// U+f5ae
#define ICON_FA_PENNANT "\xef\x91\x96"	// U+f456
#define ICON_FA_PEOPLE_CARRY "\xef\x93\x8e"	// U+f4ce
#define ICON_FA_PEPPER_HOT "\xef\xa0\x96"	// U+f816
#define ICON_FA_PERCENT "\xef\x8a\x95"	// U+f295
#define ICON_FA_PERCENTAGE "\xef\x95\x81"	// U+f541
#define ICON_FA_PERSON_BOOTH "\xef\x9d\x96"	// U+f756
#define ICON_FA_PERSON_CARRY "\xef\x93\x8f"	// U+f4cf
#define ICON_FA_PERSON_DOLLY "\xef\x93\x90"	// U+f4d0
#define ICON_FA_PERSON_DOLLY_EMPTY "\xef\x93\x91"	// U+f4d1
#define ICON_FA_PERSON_SIGN "\xef\x9d\x97"	// U+f757
#define ICON_FA_PHONE "\xef\x82\x95"	// U+f095
#define ICON_FA_PHONE_ALT "\xef\xa1\xb9"	// U+f879
#define ICON_FA_PHONE_LAPTOP "\xef\xa1\xba"	// U+f87a
#define ICON_FA_PHONE_OFFICE "\xef\x99\xbd"	// U+f67d
#define ICON_FA_PHONE_PLUS "\xef\x93\x92"	// U+f4d2
#define ICON_FA_PHONE_ROTARY "\xef\xa3\x93"	// U+f8d3
#define ICON_FA_PHONE_SLASH "\xef\x8f\x9d"	// U+f3dd
#define ICON_FA_PHONE_SQUARE "\xef\x82\x98"	// U+f098
#define ICON_FA_PHONE_SQUARE_ALT "\xef\xa1\xbb"	// U+f87b
#define ICON_FA_PHONE_VOLUME "\xef\x8a\xa0"	// U+f2a0
#define ICON_FA_PHOTO_VIDEO "\xef\xa1\xbc"	// U+f87c
#define ICON_FA_PI "\xef\x99\xbe"	// U+f67e
#define ICON_FA_PIANO "\xef\xa3\x94"	// U+f8d4
#define ICON_FA_PIANO_KEYBOARD "\xef\xa3\x95"	// U+f8d5
#define ICON_FA_PIE "\xef\x9c\x85"	// U+f705
#define ICON_FA_PIG "\xef\x9c\x86"	// U+f706
#define ICON_FA_PIGGY_BANK "\xef\x93\x93"	// U+f4d3
#define ICON_FA_PILLS "\xef\x92\x84"	// U+f484
#define ICON_FA_PIZZA "\xef\xa0\x97"	// U+f817
#define ICON_FA_PIZZA_SLICE "\xef\xa0\x98"	// U+f818
#define ICON_FA_PLACE_OF_WORSHIP "\xef\x99\xbf"	// U+f67f
#define ICON_FA_PLANE "\xef\x81\xb2"	// U+f072
#define ICON_FA_PLANE_ALT "\xef\x8f\x9e"	// U+f3de
#define ICON_FA_PLANE_ARRIVAL "\xef\x96\xaf"	// U+f5af
#define ICON_FA_PLANE_DEPARTURE "\xef\x96\xb0"	// U+f5b0
#define ICON_FA_PLANET_MOON "\xef\xa4\x9f"	// U+f91f
#define ICON_FA_PLANET_RINGED "\xef\xa4\xa0"	// U+f920
#define ICON_FA_PLAY "\xef\x81\x8b"	// U+f04b
#define ICON_FA_PLAY_CIRCLE "\xef\x85\x84"	// U+f144
#define ICON_FA_PLUG "\xef\x87\xa6"	// U+f1e6
#define ICON_FA_PLUS "\xef\x81\xa7"	// U+f067
#define ICON_FA_PLUS_CIRCLE "\xef\x81\x95"	// U+f055
#define ICON_FA_PLUS_HEXAGON "\xef\x8c\x80"	// U+f300
#define ICON_FA_PLUS_OCTAGON "\xef\x8c\x81"	// U+f301
#define ICON_FA_PLUS_SQUARE "\xef\x83\xbe"	// U+f0fe
#define ICON_FA_PODCAST "\xef\x8b\x8e"	// U+f2ce
#define ICON_FA_PODIUM "\xef\x9a\x80"	// U+f680
#define ICON_FA_PODIUM_STAR "\xef\x9d\x98"	// U+f758
#define ICON_FA_POLICE_BOX "\xef\xa4\xa1"	// U+f921
#define ICON_FA_POLL "\xef\x9a\x81"	// U+f681
#define ICON_FA_POLL_H "\xef\x9a\x82"	// U+f682
#define ICON_FA_POLL_PEOPLE "\xef\x9d\x99"	// U+f759
#define ICON_FA_POO "\xef\x8b\xbe"	// U+f2fe
#define ICON_FA_POO_STORM "\xef\x9d\x9a"	// U+f75a
#define ICON_FA_POOP "\xef\x98\x99"	// U+f619
#define ICON_FA_POPCORN "\xef\xa0\x99"	// U+f819
#define ICON_FA_PORTAL_ENTER "\xef\xa4\xa2"	// U+f922
#define ICON_FA_PORTAL_EXIT "\xef\xa4\xa3"	// U+f923
#define ICON_FA_PORTRAIT "\xef\x8f\xa0"	// U+f3e0
#define ICON_FA_POUND_SIGN "\xef\x85\x94"	// U+f154
#define ICON_FA_POWER_OFF "\xef\x80\x91"	// U+f011
#define ICON_FA_PRAY "\xef\x9a\x83"	// U+f683
#define ICON_FA_PRAYING_HANDS "\xef\x9a\x84"	// U+f684
#define ICON_FA_PRESCRIPTION "\xef\x96\xb1"	// U+f5b1
#define ICON_FA_PRESCRIPTION_BOTTLE "\xef\x92\x85"	// U+f485
#define ICON_FA_PRESCRIPTION_BOTTLE_ALT "\xef\x92\x86"	// U+f486
#define ICON_FA_PRESENTATION "\xef\x9a\x85"	// U+f685
#define ICON_FA_PRINT "\xef\x80\xaf"	// U+f02f
#define ICON_FA_PRINT_SEARCH "\xef\xa0\x9a"	// U+f81a
#define ICON_FA_PRINT_SLASH "\xef\x9a\x86"	// U+f686
#define ICON_FA_PROCEDURES "\xef\x92\x87"	// U+f487
#define ICON_FA_PROJECT_DIAGRAM "\xef\x95\x82"	// U+f542
#define ICON_FA_PROJECTOR "\xef\xa3\x96"	// U+f8d6
#define ICON_FA_PUMPKIN "\xef\x9c\x87"	// U+f707
#define ICON_FA_PUZZLE_PIECE "\xef\x84\xae"	// U+f12e
#define ICON_FA_QRCODE "\xef\x80\xa9"	// U+f029
#define ICON_FA_QUESTION "\xef\x84\xa8"	// U+f128
#define ICON_FA_QUESTION_CIRCLE "\xef\x81\x99"	// U+f059
#define ICON_FA_QUESTION_SQUARE "\xef\x8b\xbd"	// U+f2fd
#define ICON_FA_QUIDDITCH "\xef\x91\x98"	// U+f458
#define ICON_FA_QUOTE_LEFT "\xef\x84\x8d"	// U+f10d
#define ICON_FA_QUOTE_RIGHT "\xef\x84\x8e"	// U+f10e
#define ICON_FA_QURAN "\xef\x9a\x87"	// U+f687
#define ICON_FA_RABBIT "\xef\x9c\x88"	// U+f708
#define ICON_FA_RABBIT_FAST "\xef\x9c\x89"	// U+f709
#define ICON_FA_RACQUET "\xef\x91\x9a"	// U+f45a
#define ICON_FA_RADAR "\xef\xa4\xa4"	// U+f924
#define ICON_FA_RADIATION "\xef\x9e\xb9"	// U+f7b9
#define ICON_FA_RADIATION_ALT "\xef\x9e\xba"	// U+f7ba
#define ICON_FA_RADIO "\xef\xa3\x97"	// U+f8d7
#define ICON_FA_RADIO_ALT "\xef\xa3\x98"	// U+f8d8
#define ICON_FA_RAINBOW "\xef\x9d\x9b"	// U+f75b
#define ICON_FA_RAINDROPS "\xef\x9d\x9c"	// U+f75c
#define ICON_FA_RAM "\xef\x9c\x8a"	// U+f70a
#define ICON_FA_RAMP_LOADING "\xef\x93\x94"	// U+f4d4
#define ICON_FA_RANDOM "\xef\x81\xb4"	// U+f074
#define ICON_FA_RAYGUN "\xef\xa4\xa5"	// U+f925
#define ICON_FA_RECEIPT "\xef\x95\x83"	// U+f543
#define ICON_FA_RECORD_VINYL "\xef\xa3\x99"	// U+f8d9
#define ICON_FA_RECTANGLE_LANDSCAPE "\xef\x8b\xba"	// U+f2fa
#define ICON_FA_RECTANGLE_PORTRAIT "\xef\x8b\xbb"	// U+f2fb
#define ICON_FA_RECTANGLE_WIDE "\xef\x8b\xbc"	// U+f2fc
#define ICON_FA_RECYCLE "\xef\x86\xb8"	// U+f1b8
#define ICON_FA_REDO "\xef\x80\x9e"	// U+f01e
#define ICON_FA_REDO_ALT "\xef\x8b\xb9"	// U+f2f9
#define ICON_FA_REFRIGERATOR "\xef\xa4\xa6"	// U+f926
#define ICON_FA_REGISTERED "\xef\x89\x9d"	// U+f25d
#define ICON_FA_REMOVE_FORMAT "\xef\xa1\xbd"	// U+f87d
#define ICON_FA_REPEAT "\xef\x8d\xa3"	// U+f363
#define ICON_FA_REPEAT_1 "\xef\x8d\xa5"	// U+f365
#define ICON_FA_REPEAT_1_ALT "\xef\x8d\xa6"	// U+f366
#define ICON_FA_REPEAT_ALT "\xef\x8d\xa4"	// U+f364
#define ICON_FA_REPLY "\xef\x8f\xa5"	// U+f3e5
#define ICON_FA_REPLY_ALL "\xef\x84\xa2"	// U+f122
#define ICON_FA_REPUBLICAN "\xef\x9d\x9e"	// U+f75e
#define ICON_FA_RESTROOM "\xef\x9e\xbd"	// U+f7bd
#define ICON_FA_RETWEET "\xef\x81\xb9"	// U+f079
#define ICON_FA_RETWEET_ALT "\xef\x8d\xa1"	// U+f361
#define ICON_FA_RIBBON "\xef\x93\x96"	// U+f4d6
#define ICON_FA_RING "\xef\x9c\x8b"	// U+f70b
#define ICON_FA_RINGS_WEDDING "\xef\xa0\x9b"	// U+f81b
#define ICON_FA_ROAD "\xef\x80\x98"	// U+f018
#define ICON_FA_ROBOT "\xef\x95\x84"	// U+f544
#define ICON_FA_ROCKET "\xef\x84\xb5"	// U+f135
#define ICON_FA_ROCKET_LAUNCH "\xef\xa4\xa7"	// U+f927
#define ICON_FA_ROUTE "\xef\x93\x97"	// U+f4d7
#define ICON_FA_ROUTE_HIGHWAY "\xef\x98\x9a"	// U+f61a
#define ICON_FA_ROUTE_INTERSTATE "\xef\x98\x9b"	// U+f61b
#define ICON_FA_ROUTER "\xef\xa3\x9a"	// U+f8da
#define ICON_FA_RSS "\xef\x82\x9e"	// U+f09e
#define ICON_FA_RSS_SQUARE "\xef\x85\x83"	// U+f143
#define ICON_FA_RUBLE_SIGN "\xef\x85\x98"	// U+f158
#define ICON_FA_RULER "\xef\x95\x85"	// U+f545
#define ICON_FA_RULER_COMBINED "\xef\x95\x86"	// U+f546
#define ICON_FA_RULER_HORIZONTAL "\xef\x95\x87"	// U+f547
#define ICON_FA_RULER_TRIANGLE "\xef\x98\x9c"	// U+f61c
#define ICON_FA_RULER_VERTICAL "\xef\x95\x88"	// U+f548
#define ICON_FA_RUNNING "\xef\x9c\x8c"	// U+f70c
#define ICON_FA_RUPEE_SIGN "\xef\x85\x96"	// U+f156
#define ICON_FA_RV "\xef\x9e\xbe"	// U+f7be
#define ICON_FA_SACK "\xef\xa0\x9c"	// U+f81c
#define ICON_FA_SACK_DOLLAR "\xef\xa0\x9d"	// U+f81d
#define ICON_FA_SAD_CRY "\xef\x96\xb3"	// U+f5b3
#define ICON_FA_SAD_TEAR "\xef\x96\xb4"	// U+f5b4
#define ICON_FA_SALAD "\xef\xa0\x9e"	// U+f81e
#define ICON_FA_SANDWICH "\xef\xa0\x9f"	// U+f81f
#define ICON_FA_SATELLITE "\xef\x9e\xbf"	// U+f7bf
#define ICON_FA_SATELLITE_DISH "\xef\x9f\x80"	// U+f7c0
#define ICON_FA_SAUSAGE "\xef\xa0\xa0"	// U+f820
#define ICON_FA_SAVE "\xef\x83\x87"	// U+f0c7
#define ICON_FA_SAX_HOT "\xef\xa3\x9b"	// U+f8db
#define ICON_FA_SAXOPHONE "\xef\xa3\x9c"	// U+f8dc
#define ICON_FA_SCALPEL "\xef\x98\x9d"	// U+f61d
#define ICON_FA_SCALPEL_PATH "\xef\x98\x9e"	// U+f61e
#define ICON_FA_SCANNER "\xef\x92\x88"	// U+f488
#define ICON_FA_SCANNER_IMAGE "\xef\xa3\xb3"	// U+f8f3
#define ICON_FA_SCANNER_KEYBOARD "\xef\x92\x89"	// U+f489
#define ICON_FA_SCANNER_TOUCHSCREEN "\xef\x92\x8a"	// U+f48a
#define ICON_FA_SCARECROW "\xef\x9c\x8d"	// U+f70d
#define ICON_FA_SCARF "\xef\x9f\x81"	// U+f7c1
#define ICON_FA_SCHOOL "\xef\x95\x89"	// U+f549
#define ICON_FA_SCREWDRIVER "\xef\x95\x8a"	// U+f54a
#define ICON_FA_SCROLL "\xef\x9c\x8e"	// U+f70e
#define ICON_FA_SCROLL_OLD "\xef\x9c\x8f"	// U+f70f
#define ICON_FA_SCRUBBER "\xef\x8b\xb8"	// U+f2f8
#define ICON_FA_SCYTHE "\xef\x9c\x90"	// U+f710
#define ICON_FA_SD_CARD "\xef\x9f\x82"	// U+f7c2
#define ICON_FA_SEARCH "\xef\x80\x82"	// U+f002
#define ICON_FA_SEARCH_DOLLAR "\xef\x9a\x88"	// U+f688
#define ICON_FA_SEARCH_LOCATION "\xef\x9a\x89"	// U+f689
#define ICON_FA_SEARCH_MINUS "\xef\x80\x90"	// U+f010
#define ICON_FA_SEARCH_PLUS "\xef\x80\x8e"	// U+f00e
#define ICON_FA_SEEDLING "\xef\x93\x98"	// U+f4d8
#define ICON_FA_SEND_BACK "\xef\xa1\xbe"	// U+f87e
#define ICON_FA_SEND_BACKWARD "\xef\xa1\xbf"	// U+f87f
#define ICON_FA_SENSOR "\xef\xa4\xa8"	// U+f928
#define ICON_FA_SENSOR_ALERT "\xef\xa4\xa9"	// U+f929
#define ICON_FA_SENSOR_FIRE "\xef\xa4\xaa"	// U+f92a
#define ICON_FA_SENSOR_ON "\xef\xa4\xab"	// U+f92b
#define ICON_FA_SENSOR_SMOKE "\xef\xa4\xac"	// U+f92c
#define ICON_FA_SERVER "\xef\x88\xb3"	// U+f233
#define ICON_FA_SHAPES "\xef\x98\x9f"	// U+f61f
#define ICON_FA_SHARE "\xef\x81\xa4"	// U+f064
#define ICON_FA_SHARE_ALL "\xef\x8d\xa7"	// U+f367
#define ICON_FA_SHARE_ALT "\xef\x87\xa0"	// U+f1e0
#define ICON_FA_SHARE_ALT_SQUARE "\xef\x87\xa1"	// U+f1e1
#define ICON_FA_SHARE_SQUARE "\xef\x85\x8d"	// U+f14d
#define ICON_FA_SHEEP "\xef\x9c\x91"	// U+f711
#define ICON_FA_SHEKEL_SIGN "\xef\x88\x8b"	// U+f20b
#define ICON_FA_SHIELD "\xef\x84\xb2"	// U+f132
#define ICON_FA_SHIELD_ALT "\xef\x8f\xad"	// U+f3ed
#define ICON_FA_SHIELD_CHECK "\xef\x8b\xb7"	// U+f2f7
#define ICON_FA_SHIELD_CROSS "\xef\x9c\x92"	// U+f712
#define ICON_FA_SHIP "\xef\x88\x9a"	// U+f21a
#define ICON_FA_SHIPPING_FAST "\xef\x92\x8b"	// U+f48b
#define ICON_FA_SHIPPING_TIMED "\xef\x92\x8c"	// U+f48c
#define ICON_FA_SHISH_KEBAB "\xef\xa0\xa1"	// U+f821
#define ICON_FA_SHOE_PRINTS "\xef\x95\x8b"	// U+f54b
#define ICON_FA_SHOPPING_BAG "\xef\x8a\x90"	// U+f290
#define ICON_FA_SHOPPING_BASKET "\xef\x8a\x91"	// U+f291
#define ICON_FA_SHOPPING_CART "\xef\x81\xba"	// U+f07a
#define ICON_FA_SHOVEL "\xef\x9c\x93"	// U+f713
#define ICON_FA_SHOVEL_SNOW "\xef\x9f\x83"	// U+f7c3
#define ICON_FA_SHOWER "\xef\x8b\x8c"	// U+f2cc
#define ICON_FA_SHREDDER "\xef\x9a\x8a"	// U+f68a
#define ICON_FA_SHUTTLE_VAN "\xef\x96\xb6"	// U+f5b6
#define ICON_FA_SHUTTLECOCK "\xef\x91\x9b"	// U+f45b
#define ICON_FA_SICKLE "\xef\xa0\xa2"	// U+f822
#define ICON_FA_SIGMA "\xef\x9a\x8b"	// U+f68b
#define ICON_FA_SIGN "\xef\x93\x99"	// U+f4d9
#define ICON_FA_SIGN_IN "\xef\x82\x90"	// U+f090
#define ICON_FA_SIGN_IN_ALT "\xef\x8b\xb6"	// U+f2f6
#define ICON_FA_SIGN_LANGUAGE "\xef\x8a\xa7"	// U+f2a7
#define ICON_FA_SIGN_OUT "\xef\x82\x8b"	// U+f08b
#define ICON_FA_SIGN_OUT_ALT "\xef\x8b\xb5"	// U+f2f5
#define ICON_FA_SIGNAL "\xef\x80\x92"	// U+f012
#define ICON_FA_SIGNAL_1 "\xef\x9a\x8c"	// U+f68c
#define ICON_FA_SIGNAL_2 "\xef\x9a\x8d"	// U+f68d
#define ICON_FA_SIGNAL_3 "\xef\x9a\x8e"	// U+f68e
#define ICON_FA_SIGNAL_4 "\xef\x9a\x8f"	// U+f68f
#define ICON_FA_SIGNAL_ALT "\xef\x9a\x90"	// U+f690
#define ICON_FA_SIGNAL_ALT_1 "\xef\x9a\x91"	// U+f691
#define ICON_FA_SIGNAL_ALT_2 "\xef\x9a\x92"	// U+f692
#define ICON_FA_SIGNAL_ALT_3 "\xef\x9a\x93"	// U+f693
#define ICON_FA_SIGNAL_ALT_SLASH "\xef\x9a\x94"	// U+f694
#define ICON_FA_SIGNAL_SLASH "\xef\x9a\x95"	// U+f695
#define ICON_FA_SIGNAL_STREAM "\xef\xa3\x9d"	// U+f8dd
#define ICON_FA_SIGNATURE "\xef\x96\xb7"	// U+f5b7
#define ICON_FA_SIM_CARD "\xef\x9f\x84"	// U+f7c4
#define ICON_FA_SIREN "\xef\xa4\xad"	// U+f92d
#define ICON_FA_SIREN_ON "\xef\xa4\xae"	// U+f92e
#define ICON_FA_SITEMAP "\xef\x83\xa8"	// U+f0e8
#define ICON_FA_SKATING "\xef\x9f\x85"	// U+f7c5
#define ICON_FA_SKELETON "\xef\x98\xa0"	// U+f620
#define ICON_FA_SKI_JUMP "\xef\x9f\x87"	// U+f7c7
#define ICON_FA_SKI_LIFT "\xef\x9f\x88"	// U+f7c8
#define ICON_FA_SKIING "\xef\x9f\x89"	// U+f7c9
#define ICON_FA_SKIING_NORDIC "\xef\x9f\x8a"	// U+f7ca
#define ICON_FA_SKULL "\xef\x95\x8c"	// U+f54c
#define ICON_FA_SKULL_COW "\xef\xa3\x9e"	// U+f8de
#define ICON_FA_SKULL_CROSSBONES "\xef\x9c\x94"	// U+f714
#define ICON_FA_SLASH "\xef\x9c\x95"	// U+f715
#define ICON_FA_SLEDDING "\xef\x9f\x8b"	// U+f7cb
#define ICON_FA_SLEIGH "\xef\x9f\x8c"	// U+f7cc
#define ICON_FA_SLIDERS_H "\xef\x87\x9e"	// U+f1de
#define ICON_FA_SLIDERS_H_SQUARE "\xef\x8f\xb0"	// U+f3f0
#define ICON_FA_SLIDERS_V "\xef\x8f\xb1"	// U+f3f1
#define ICON_FA_SLIDERS_V_SQUARE "\xef\x8f\xb2"	// U+f3f2
#define ICON_FA_SMILE "\xef\x84\x98"	// U+f118
#define ICON_FA_SMILE_BEAM "\xef\x96\xb8"	// U+f5b8
#define ICON_FA_SMILE_PLUS "\xef\x96\xb9"	// U+f5b9
#define ICON_FA_SMILE_WINK "\xef\x93\x9a"	// U+f4da
#define ICON_FA_SMOG "\xef\x9d\x9f"	// U+f75f
#define ICON_FA_SMOKE "\xef\x9d\xa0"	// U+f760
#define ICON_FA_SMOKING "\xef\x92\x8d"	// U+f48d
#define ICON_FA_SMOKING_BAN "\xef\x95\x8d"	// U+f54d
#define ICON_FA_SMS "\xef\x9f\x8d"	// U+f7cd
#define ICON_FA_SNAKE "\xef\x9c\x96"	// U+f716
#define ICON_FA_SNOOZE "\xef\xa2\x80"	// U+f880
#define ICON_FA_SNOW_BLOWING "\xef\x9d\xa1"	// U+f761
#define ICON_FA_SNOWBOARDING "\xef\x9f\x8e"	// U+f7ce
#define ICON_FA_SNOWFLAKE "\xef\x8b\x9c"	// U+f2dc
#define ICON_FA_SNOWFLAKES "\xef\x9f\x8f"	// U+f7cf
#define ICON_FA_SNOWMAN "\xef\x9f\x90"	// U+f7d0
#define ICON_FA_SNOWMOBILE "\xef\x9f\x91"	// U+f7d1
#define ICON_FA_SNOWPLOW "\xef\x9f\x92"	// U+f7d2
#define ICON_FA_SOCKS "\xef\x9a\x96"	// U+f696
#define ICON_FA_SOLAR_PANEL "\xef\x96\xba"	// U+f5ba
#define ICON_FA_SOLAR_SYSTEM "\xef\xa4\xaf"	// U+f92f
#define ICON_FA_SORT "\xef\x83\x9c"	// U+f0dc
#define ICON_FA_SORT_ALPHA_DOWN "\xef\x85\x9d"	// U+f15d
#define ICON_FA_SORT_ALPHA_DOWN_ALT "\xef\xa2\x81"	// U+f881
#define ICON_FA_SORT_ALPHA_UP "\xef\x85\x9e"	// U+f15e
#define ICON_FA_SORT_ALPHA_UP_ALT "\xef\xa2\x82"	// U+f882
#define ICON_FA_SORT_ALT "\xef\xa2\x83"	// U+f883
#define ICON_FA_SORT_AMOUNT_DOWN "\xef\x85\xa0"	// U+f160
#define ICON_FA_SORT_AMOUNT_DOWN_ALT "\xef\xa2\x84"	// U+f884
#define ICON_FA_SORT_AMOUNT_UP "\xef\x85\xa1"	// U+f161
#define ICON_FA_SORT_AMOUNT_UP_ALT "\xef\xa2\x85"	// U+f885
#define ICON_FA_SORT_CIRCLE "\xef\xa4\xb0"	// U+f930
#define ICON_FA_SORT_CIRCLE_DOWN "\xef\xa4\xb1"	// U+f931
#define ICON_FA_SORT_CIRCLE_UP "\xef\xa4\xb2"	// U+f932
#define ICON_FA_SORT_DOWN "\xef\x83\x9d"	// U+f0dd
#define ICON_FA_SORT_NUMERIC_DOWN "\xef\x85\xa2"	// U+f162
#define ICON_FA_SORT_NUMERIC_DOWN_ALT "\xef\xa2\x86"	// U+f886
#define ICON_FA_SORT_NUMERIC_UP "\xef\x85\xa3"	// U+f163
#define ICON_FA_SORT_NUMERIC_UP_ALT "\xef\xa2\x87"	// U+f887
#define ICON_FA_SORT_SHAPES_DOWN "\xef\xa2\x88"	// U+f888
#define ICON_FA_SORT_SHAPES_DOWN_ALT "\xef\xa2\x89"	// U+f889
#define ICON_FA_SORT_SHAPES_UP "\xef\xa2\x8a"	// U+f88a
#define ICON_FA_SORT_SHAPES_UP_ALT "\xef\xa2\x8b"	// U+f88b
#define ICON_FA_SORT_SIZE_DOWN "\xef\xa2\x8c"	// U+f88c
#define ICON_FA_SORT_SIZE_DOWN_ALT "\xef\xa2\x8d"	// U+f88d
#define ICON_FA_SORT_SIZE_UP "\xef\xa2\x8e"	// U+f88e
#define ICON_FA_SORT_SIZE_UP_ALT "\xef\xa2\x8f"	// U+f88f
#define ICON_FA_SORT_UP "\xef\x83\x9e"	// U+f0de
#define ICON_FA_SOUP "\xef\xa0\xa3"	// U+f823
#define ICON_FA_SPA "\xef\x96\xbb"	// U+f5bb
#define ICON_FA_SPACE_SHUTTLE "\xef\x86\x97"	// U+f197
#define ICON_FA_SPACE_STATION_MOON "\xef\xa4\xb3"	// U+f933
#define ICON_FA_SPACE_STATION_MOON_ALT "\xef\xa4\xb4"	// U+f934
#define ICON_FA_SPADE "\xef\x8b\xb4"	// U+f2f4
#define ICON_FA_SPARKLES "\xef\xa2\x90"	// U+f890
#define ICON_FA_SPEAKER "\xef\xa3\x9f"	// U+f8df
#define ICON_FA_SPEAKERS "\xef\xa3\xa0"	// U+f8e0
#define ICON_FA_SPELL_CHECK "\xef\xa2\x91"	// U+f891
#define ICON_FA_SPIDER "\xef\x9c\x97"	// U+f717
#define ICON_FA_SPIDER_BLACK_WIDOW "\xef\x9c\x98"	// U+f718
#define ICON_FA_SPIDER_WEB "\xef\x9c\x99"	// U+f719
#define ICON_FA_SPINNER "\xef\x84\x90"	// U+f110
#define ICON_FA_SPINNER_THIRD "\xef\x8f\xb4"	// U+f3f4
#define ICON_FA_SPLOTCH "\xef\x96\xbc"	// U+f5bc
#define ICON_FA_SPRAY_CAN "\xef\x96\xbd"	// U+f5bd
#define ICON_FA_SPRINKLER "\xef\xa4\xb5"	// U+f935
#define ICON_FA_SQUARE "\xef\x83\x88"	// U+f0c8
#define ICON_FA_SQUARE_FULL "\xef\x91\x9c"	// U+f45c
#define ICON_FA_SQUARE_ROOT "\xef\x9a\x97"	// U+f697
#define ICON_FA_SQUARE_ROOT_ALT "\xef\x9a\x98"	// U+f698
#define ICON_FA_SQUIRREL "\xef\x9c\x9a"	// U+f71a
#define ICON_FA_STAFF "\xef\x9c\x9b"	// U+f71b
#define ICON_FA_STAMP "\xef\x96\xbf"	// U+f5bf
#define ICON_FA_STAR "\xef\x80\x85"	// U+f005
#define ICON_FA_STAR_AND_CRESCENT "\xef\x9a\x99"	// U+f699
#define ICON_FA_STAR_CHRISTMAS "\xef\x9f\x94"	// U+f7d4
#define ICON_FA_STAR_EXCLAMATION "\xef\x8b\xb3"	// U+f2f3
#define ICON_FA_STAR_HALF "\xef\x82\x89"	// U+f089
#define ICON_FA_STAR_HALF_ALT "\xef\x97\x80"	// U+f5c0
#define ICON_FA_STAR_OF_DAVID "\xef\x9a\x9a"	// U+f69a
#define ICON_FA_STAR_OF_LIFE "\xef\x98\xa1"	// U+f621
#define ICON_FA_STAR_SHOOTING "\xef\xa4\xb6"	// U+f936
#define ICON_FA_STARFIGHTER "\xef\xa4\xb7"	// U+f937
#define ICON_FA_STARFIGHTER_ALT "\xef\xa4\xb8"	// U+f938
#define ICON_FA_STARS "\xef\x9d\xa2"	// U+f762
#define ICON_FA_STARSHIP "\xef\xa4\xb9"	// U+f939
#define ICON_FA_STARSHIP_FREIGHTER "\xef\xa4\xba"	// U+f93a
#define ICON_FA_STEAK "\xef\xa0\xa4"	// U+f824
#define ICON_FA_STEERING_WHEEL "\xef\x98\xa2"	// U+f622
#define ICON_FA_STEP_BACKWARD "\xef\x81\x88"	// U+f048
#define ICON_FA_STEP_FORWARD "\xef\x81\x91"	// U+f051
#define ICON_FA_STETHOSCOPE "\xef\x83\xb1"	// U+f0f1
#define ICON_FA_STICKY_NOTE "\xef\x89\x89"	// U+f249
#define ICON_FA_STOCKING "\xef\x9f\x95"	// U+f7d5
#define ICON_FA_STOMACH "\xef\x98\xa3"	// U+f623
#define ICON_FA_STOP "\xef\x81\x8d"	// U+f04d
#define ICON_FA_STOP_CIRCLE "\xef\x8a\x8d"	// U+f28d
#define ICON_FA_STOPWATCH "\xef\x8b\xb2"	// U+f2f2
#define ICON_FA_STORE "\xef\x95\x8e"	// U+f54e
#define ICON_FA_STORE_ALT "\xef\x95\x8f"	// U+f54f
#define ICON_FA_STREAM "\xef\x95\x90"	// U+f550
#define ICON_FA_STREET_VIEW "\xef\x88\x9d"	// U+f21d
#define ICON_FA_STRETCHER "\xef\xa0\xa5"	// U+f825
#define ICON_FA_STRIKETHROUGH "\xef\x83\x8c"	// U+f0cc
#define ICON_FA_STROOPWAFEL "\xef\x95\x91"	// U+f551
#define ICON_FA_SUBSCRIPT "\xef\x84\xac"	// U+f12c
#define ICON_FA_SUBWAY "\xef\x88\xb9"	// U+f239
#define ICON_FA_SUITCASE "\xef\x83\xb2"	// U+f0f2
#define ICON_FA_SUITCASE_ROLLING "\xef\x97\x81"	// U+f5c1
#define ICON_FA_SUN "\xef\x86\x85"	// U+f185
#define ICON_FA_SUN_CLOUD "\xef\x9d\xa3"	// U+f763
#define ICON_FA_SUN_DUST "\xef\x9d\xa4"	// U+f764
#define ICON_FA_SUN_HAZE "\xef\x9d\xa5"	// U+f765
#define ICON_FA_SUNGLASSES "\xef\xa2\x92"	// U+f892
#define ICON_FA_SUNRISE "\xef\x9d\xa6"	// U+f766
#define ICON_FA_SUNSET "\xef\x9d\xa7"	// U+f767
#define ICON_FA_SUPERSCRIPT "\xef\x84\xab"	// U+f12b
#define ICON_FA_SURPRISE "\xef\x97\x82"	// U+f5c2
#define ICON_FA_SWATCHBOOK "\xef\x97\x83"	// U+f5c3
#define ICON_FA_SWIMMER "\xef\x97\x84"	// U+f5c4
#define ICON_FA_SWIMMING_POOL "\xef\x97\x85"	// U+f5c5
#define ICON_FA_SWORD "\xef\x9c\x9c"	// U+f71c
#define ICON_FA_SWORD_LASER "\xef\xa4\xbb"	// U+f93b
#define ICON_FA_SWORD_LASER_ALT "\xef\xa4\xbc"	// U+f93c
#define ICON_FA_SWORDS "\xef\x9c\x9d"	// U+f71d
#define ICON_FA_SWORDS_LASER "\xef\xa4\xbd"	// U+f93d
#define ICON_FA_SYNAGOGUE "\xef\x9a\x9b"	// U+f69b
#define ICON_FA_SYNC "\xef\x80\xa1"	// U+f021
#define ICON_FA_SYNC_ALT "\xef\x8b\xb1"	// U+f2f1
#define ICON_FA_SYRINGE "\xef\x92\x8e"	// U+f48e
#define ICON_FA_TABLE "\xef\x83\x8e"	// U+f0ce
#define ICON_FA_TABLE_TENNIS "\xef\x91\x9d"	// U+f45d
#define ICON_FA_TABLET "\xef\x84\x8a"	// U+f10a
#define ICON_FA_TABLET_ALT "\xef\x8f\xba"	// U+f3fa
#define ICON_FA_TABLET_ANDROID "\xef\x8f\xbb"	// U+f3fb
#define ICON_FA_TABLET_ANDROID_ALT "\xef\x8f\xbc"	// U+f3fc
#define ICON_FA_TABLET_RUGGED "\xef\x92\x8f"	// U+f48f
#define ICON_FA_TABLETS "\xef\x92\x90"	// U+f490
#define ICON_FA_TACHOMETER "\xef\x83\xa4"	// U+f0e4
#define ICON_FA_TACHOMETER_ALT "\xef\x8f\xbd"	// U+f3fd
#define ICON_FA_TACHOMETER_ALT_AVERAGE "\xef\x98\xa4"	// U+f624
#define ICON_FA_TACHOMETER_ALT_FAST "\xef\x98\xa5"	// U+f625
#define ICON_FA_TACHOMETER_ALT_FASTEST "\xef\x98\xa6"	// U+f626
#define ICON_FA_TACHOMETER_ALT_SLOW "\xef\x98\xa7"	// U+f627
#define ICON_FA_TACHOMETER_ALT_SLOWEST "\xef\x98\xa8"	// U+f628
#define ICON_FA_TACHOMETER_AVERAGE "\xef\x98\xa9"	// U+f629
#define ICON_FA_TACHOMETER_FAST "\xef\x98\xaa"	// U+f62a
#define ICON_FA_TACHOMETER_FASTEST "\xef\x98\xab"	// U+f62b
#define ICON_FA_TACHOMETER_SLOW "\xef\x98\xac"	// U+f62c
#define ICON_FA_TACHOMETER_SLOWEST "\xef\x98\xad"	// U+f62d
#define ICON_FA_TACO "\xef\xa0\xa6"	// U+f826
#define ICON_FA_TAG "\xef\x80\xab"	// U+f02b
#define ICON_FA_TAGS "\xef\x80\xac"	// U+f02c
#define ICON_FA_TALLY "\xef\x9a\x9c"	// U+f69c
#define ICON_FA_TANAKH "\xef\xa0\xa7"	// U+f827
#define ICON_FA_TAPE "\xef\x93\x9b"	// U+f4db
#define ICON_FA_TASKS "\xef\x82\xae"	// U+f0ae
#define ICON_FA_TASKS_ALT "\xef\xa0\xa8"	// U+f828
#define ICON_FA_TAXI "\xef\x86\xba"	// U+f1ba
#define ICON_FA_TEETH "\xef\x98\xae"	// U+f62e
#define ICON_FA_TEETH_OPEN "\xef\x98\xaf"	// U+f62f
#define ICON_FA_TELESCOPE "\xef\xa4\xbe"	// U+f93e
#define ICON_FA_TEMPERATURE_DOWN "\xef\xa4\xbf"	// U+f93f
#define ICON_FA_TEMPERATURE_FRIGID "\xef\x9d\xa8"	// U+f768
#define ICON_FA_TEMPERATURE_HIGH "\xef\x9d\xa9"	// U+f769
#define ICON_FA_TEMPERATURE_HOT "\xef\x9d\xaa"	// U+f76a
#define ICON_FA_TEMPERATURE_LOW "\xef\x9d\xab"	// U+f76b
#define ICON_FA_TEMPERATURE_UP "\xef\xa5\x80"	// U+f940
#define ICON_FA_TENGE "\xef\x9f\x97"	// U+f7d7
#define ICON_FA_TENNIS_BALL "\xef\x91\x9e"	// U+f45e
#define ICON_FA_TERMINAL "\xef\x84\xa0"	// U+f120
#define ICON_FA_TEXT "\xef\xa2\x93"	// U+f893
#define ICON_FA_TEXT_HEIGHT "\xef\x80\xb4"	// U+f034
#define ICON_FA_TEXT_SIZE "\xef\xa2\x94"	// U+f894
#define ICON_FA_TEXT_WIDTH "\xef\x80\xb5"	// U+f035
#define ICON_FA_TH "\xef\x80\x8a"	// U+f00a
#define ICON_FA_TH_LARGE "\xef\x80\x89"	// U+f009
#define ICON_FA_TH_LIST "\xef\x80\x8b"	// U+f00b
#define ICON_FA_THEATER_MASKS "\xef\x98\xb0"	// U+f630
#define ICON_FA_THERMOMETER "\xef\x92\x91"	// U+f491
#define ICON_FA_THERMOMETER_EMPTY "\xef\x8b\x8b"	// U+f2cb
#define ICON_FA_THERMOMETER_FULL "\xef\x8b\x87"	// U+f2c7
#define ICON_FA_THERMOMETER_HALF "\xef\x8b\x89"	// U+f2c9
#define ICON_FA_THERMOMETER_QUARTER "\xef\x8b\x8a"	// U+f2ca
#define ICON_FA_THERMOMETER_THREE_QUARTERS "\xef\x8b\x88"	// U+f2c8
#define ICON_FA_THETA "\xef\x9a\x9e"	// U+f69e
#define ICON_FA_THUMBS_DOWN "\xef\x85\xa5"	// U+f165
#define ICON_FA_THUMBS_UP "\xef\x85\xa4"	// U+f164
#define ICON_FA_THUMBTACK "\xef\x82\x8d"	// U+f08d
#define ICON_FA_THUNDERSTORM "\xef\x9d\xac"	// U+f76c
#define ICON_FA_THUNDERSTORM_MOON "\xef\x9d\xad"	// U+f76d
#define ICON_FA_THUNDERSTORM_SUN "\xef\x9d\xae"	// U+f76e
#define ICON_FA_TICKET "\xef\x85\x85"	// U+f145
#define ICON_FA_TICKET_ALT "\xef\x8f\xbf"	// U+f3ff
#define ICON_FA_TILDE "\xef\x9a\x9f"	// U+f69f
#define ICON_FA_TIMES "\xef\x80\x8d"	// U+f00d
#define ICON_FA_TIMES_CIRCLE "\xef\x81\x97"	// U+f057
#define ICON_FA_TIMES_HEXAGON "\xef\x8b\xae"	// U+f2ee
#define ICON_FA_TIMES_OCTAGON "\xef\x8b\xb0"	// U+f2f0
#define ICON_FA_TIMES_SQUARE "\xef\x8b\x93"	// U+f2d3
#define ICON_FA_TINT "\xef\x81\x83"	// U+f043
#define ICON_FA_TINT_SLASH "\xef\x97\x87"	// U+f5c7
#define ICON_FA_TIRE "\xef\x98\xb1"	// U+f631
#define ICON_FA_TIRE_FLAT "\xef\x98\xb2"	// U+f632
#define ICON_FA_TIRE_PRESSURE_WARNING "\xef\x98\xb3"	// U+f633
#define ICON_FA_TIRE_RUGGED "\xef\x98\xb4"	// U+f634
#define ICON_FA_TIRED "\xef\x97\x88"	// U+f5c8
#define ICON_FA_TOGGLE_OFF "\xef\x88\x84"	// U+f204
#define ICON_FA_TOGGLE_ON "\xef\x88\x85"	// U+f205
#define ICON_FA_TOILET "\xef\x9f\x98"	// U+f7d8
#define ICON_FA_TOILET_PAPER "\xef\x9c\x9e"	// U+f71e
#define ICON_FA_TOILET_PAPER_ALT "\xef\x9c\x9f"	// U+f71f
#define ICON_FA_TOMBSTONE "\xef\x9c\xa0"	// U+f720
#define ICON_FA_TOMBSTONE_ALT "\xef\x9c\xa1"	// U+f721
#define ICON_FA_TOOLBOX "\xef\x95\x92"	// U+f552
#define ICON_FA_TOOLS "\xef\x9f\x99"	// U+f7d9
#define ICON_FA_TOOTH "\xef\x97\x89"	// U+f5c9
#define ICON_FA_TOOTHBRUSH "\xef\x98\xb5"	// U+f635
#define ICON_FA_TORAH "\xef\x9a\xa0"	// U+f6a0
#define ICON_FA_TORII_GATE "\xef\x9a\xa1"	// U+f6a1
#define ICON_FA_TORNADO "\xef\x9d\xaf"	// U+f76f
#define ICON_FA_TRACTOR "\xef\x9c\xa2"	// U+f722
#define ICON_FA_TRADEMARK "\xef\x89\x9c"	// U+f25c
#define ICON_FA_TRAFFIC_CONE "\xef\x98\xb6"	// U+f636
#define ICON_FA_TRAFFIC_LIGHT "\xef\x98\xb7"	// U+f637
#define ICON_FA_TRAFFIC_LIGHT_GO "\xef\x98\xb8"	// U+f638
#define ICON_FA_TRAFFIC_LIGHT_SLOW "\xef\x98\xb9"	// U+f639
#define ICON_FA_TRAFFIC_LIGHT_STOP "\xef\x98\xba"	// U+f63a
#define ICON_FA_TRAILER "\xef\xa5\x81"	// U+f941
#define ICON_FA_TRAIN "\xef\x88\xb8"	// U+f238
#define ICON_FA_TRAM "\xef\x9f\x9a"	// U+f7da
#define ICON_FA_TRANSGENDER "\xef\x88\xa4"	// U+f224
#define ICON_FA_TRANSGENDER_ALT "\xef\x88\xa5"	// U+f225
#define ICON_FA_TRANSPORTER "\xef\xa5\x82"	// U+f942
#define ICON_FA_TRANSPORTER_1 "\xef\xa5\x83"	// U+f943
#define ICON_FA_TRANSPORTER_2 "\xef\xa5\x84"	// U+f944
#define ICON_FA_TRANSPORTER_3 "\xef\xa5\x85"	// U+f945
#define ICON_FA_TRANSPORTER_EMPTY "\xef\xa5\x86"	// U+f946
#define ICON_FA_TRASH "\xef\x87\xb8"	// U+f1f8
#define ICON_FA_TRASH_ALT "\xef\x8b\xad"	// U+f2ed
#define ICON_FA_TRASH_RESTORE "\xef\xa0\xa9"	// U+f829
#define ICON_FA_TRASH_RESTORE_ALT "\xef\xa0\xaa"	// U+f82a
#define ICON_FA_TRASH_UNDO "\xef\xa2\x95"	// U+f895
#define ICON_FA_TRASH_UNDO_ALT "\xef\xa2\x96"	// U+f896
#define ICON_FA_TREASURE_CHEST "\xef\x9c\xa3"	// U+f723
#define ICON_FA_TREE "\xef\x86\xbb"	// U+f1bb
#define ICON_FA_TREE_ALT "\xef\x90\x80"	// U+f400
#define ICON_FA_TREE_CHRISTMAS "\xef\x9f\x9b"	// U+f7db
#define ICON_FA_TREE_DECORATED "\xef\x9f\x9c"	// U+f7dc
#define ICON_FA_TREE_LARGE "\xef\x9f\x9d"	// U+f7dd
#define ICON_FA_TREE_PALM "\xef\xa0\xab"	// U+f82b
#define ICON_FA_TREES "\xef\x9c\xa4"	// U+f724
#define ICON_FA_TRIANGLE "\xef\x8b\xac"	// U+f2ec
#define ICON_FA_TRIANGLE_MUSIC "\xef\xa3\xa2"	// U+f8e2
#define ICON_FA_TROPHY "\xef\x82\x91"	// U+f091
#define ICON_FA_TROPHY_ALT "\xef\x8b\xab"	// U+f2eb
#define ICON_FA_TRUCK "\xef\x83\x91"	// U+f0d1
#define ICON_FA_TRUCK_CONTAINER "\xef\x93\x9c"	// U+f4dc
#define ICON_FA_TRUCK_COUCH "\xef\x93\x9d"	// U+f4dd
#define ICON_FA_TRUCK_LOADING "\xef\x93\x9e"	// U+f4de
#define ICON_FA_TRUCK_MONSTER "\xef\x98\xbb"	// U+f63b
#define ICON_FA_TRUCK_MOVING "\xef\x93\x9f"	// U+f4df
#define ICON_FA_TRUCK_PICKUP "\xef\x98\xbc"	// U+f63c
#define ICON_FA_TRUCK_PLOW "\xef\x9f\x9e"	// U+f7de
#define ICON_FA_TRUCK_RAMP "\xef\x93\xa0"	// U+f4e0
#define ICON_FA_TRUMPET "\xef\xa3\xa3"	// U+f8e3
#define ICON_FA_TSHIRT "\xef\x95\x93"	// U+f553
#define ICON_FA_TTY "\xef\x87\xa4"	// U+f1e4
#define ICON_FA_TURKEY "\xef\x9c\xa5"	// U+f725
#define ICON_FA_TURNTABLE "\xef\xa3\xa4"	// U+f8e4
#define ICON_FA_TURTLE "\xef\x9c\xa6"	// U+f726
#define ICON_FA_TV "\xef\x89\xac"	// U+f26c
#define ICON_FA_TV_ALT "\xef\xa3\xa5"	// U+f8e5
#define ICON_FA_TV_MUSIC "\xef\xa3\xa6"	// U+f8e6
#define ICON_FA_TV_RETRO "\xef\x90\x81"	// U+f401
#define ICON_FA_TYPEWRITER "\xef\xa3\xa7"	// U+f8e7
#define ICON_FA_UFO "\xef\xa5\x87"	// U+f947
#define ICON_FA_UFO_BEAM "\xef\xa5\x88"	// U+f948
#define ICON_FA_UMBRELLA "\xef\x83\xa9"	// U+f0e9
#define ICON_FA_UMBRELLA_BEACH "\xef\x97\x8a"	// U+f5ca
#define ICON_FA_UNDERLINE "\xef\x83\x8d"	// U+f0cd
#define ICON_FA_UNDO "\xef\x83\xa2"	// U+f0e2
#define ICON_FA_UNDO_ALT "\xef\x8b\xaa"	// U+f2ea
#define ICON_FA_UNICORN "\xef\x9c\xa7"	// U+f727
#define ICON_FA_UNION "\xef\x9a\xa2"	// U+f6a2
#define ICON_FA_UNIVERSAL_ACCESS "\xef\x8a\x9a"	// U+f29a
#define ICON_FA_UNIVERSITY "\xef\x86\x9c"	// U+f19c
#define ICON_FA_UNLINK "\xef\x84\xa7"	// U+f127
#define ICON_FA_UNLOCK "\xef\x82\x9c"	// U+f09c
#define ICON_FA_UNLOCK_ALT "\xef\x84\xbe"	// U+f13e
#define ICON_FA_UPLOAD "\xef\x82\x93"	// U+f093
#define ICON_FA_USB_DRIVE "\xef\xa3\xa9"	// U+f8e9
#define ICON_FA_USD_CIRCLE "\xef\x8b\xa8"	// U+f2e8
#define ICON_FA_USD_SQUARE "\xef\x8b\xa9"	// U+f2e9
#define ICON_FA_USER "\xef\x80\x87"	// U+f007
#define ICON_FA_USER_ALIEN "\xef\xa5\x8a"	// U+f94a
#define ICON_FA_USER_ALT "\xef\x90\x86"	// U+f406
#define ICON_FA_USER_ALT_SLASH "\xef\x93\xba"	// U+f4fa
#define ICON_FA_USER_ASTRONAUT "\xef\x93\xbb"	// U+f4fb
#define ICON_FA_USER_CHART "\xef\x9a\xa3"	// U+f6a3
#define ICON_FA_USER_CHECK "\xef\x93\xbc"	// U+f4fc
#define ICON_FA_USER_CIRCLE "\xef\x8a\xbd"	// U+f2bd
#define ICON_FA_USER_CLOCK "\xef\x93\xbd"	// U+f4fd
#define ICON_FA_USER_COG "\xef\x93\xbe"	// U+f4fe
#define ICON_FA_USER_COWBOY "\xef\xa3\xaa"	// U+f8ea
#define ICON_FA_USER_CROWN "\xef\x9a\xa4"	// U+f6a4
#define ICON_FA_USER_EDIT "\xef\x93\xbf"	// U+f4ff
#define ICON_FA_USER_FRIENDS "\xef\x94\x80"	// U+f500
#define ICON_FA_USER_GRADUATE "\xef\x94\x81"	// U+f501
#define ICON_FA_USER_HARD_HAT "\xef\xa0\xac"	// U+f82c
#define ICON_FA_USER_HEADSET "\xef\xa0\xad"	// U+f82d
#define ICON_FA_USER_INJURED "\xef\x9c\xa8"	// U+f728
#define ICON_FA_USER_LOCK "\xef\x94\x82"	// U+f502
#define ICON_FA_USER_MD "\xef\x83\xb0"	// U+f0f0
#define ICON_FA_USER_MD_CHAT "\xef\xa0\xae"	// U+f82e
#define ICON_FA_USER_MINUS "\xef\x94\x83"	// U+f503
#define ICON_FA_USER_MUSIC "\xef\xa3\xab"	// U+f8eb
#define ICON_FA_USER_NINJA "\xef\x94\x84"	// U+f504
#define ICON_FA_USER_NURSE "\xef\xa0\xaf"	// U+f82f
#define ICON_FA_USER_PLUS "\xef\x88\xb4"	// U+f234
#define ICON_FA_USER_ROBOT "\xef\xa5\x8b"	// U+f94b
#define ICON_FA_USER_SECRET "\xef\x88\x9b"	// U+f21b
#define ICON_FA_USER_SHIELD "\xef\x94\x85"	// U+f505
#define ICON_FA_USER_SLASH "\xef\x94\x86"	// U+f506
#define ICON_FA_USER_TAG "\xef\x94\x87"	// U+f507
#define ICON_FA_USER_TIE "\xef\x94\x88"	// U+f508
#define ICON_FA_USER_TIMES "\xef\x88\xb5"	// U+f235
#define ICON_FA_USER_VISOR "\xef\xa5\x8c"	// U+f94c
#define ICON_FA_USERS "\xef\x83\x80"	// U+f0c0
#define ICON_FA_USERS_CLASS "\xef\x98\xbd"	// U+f63d
#define ICON_FA_USERS_COG "\xef\x94\x89"	// U+f509
#define ICON_FA_USERS_CROWN "\xef\x9a\xa5"	// U+f6a5
#define ICON_FA_USERS_MEDICAL "\xef\xa0\xb0"	// U+f830
#define ICON_FA_UTENSIL_FORK "\xef\x8b\xa3"	// U+f2e3
#define ICON_FA_UTENSIL_KNIFE "\xef\x8b\xa4"	// U+f2e4
#define ICON_FA_UTENSIL_SPOON "\xef\x8b\xa5"	// U+f2e5
#define ICON_FA_UTENSILS "\xef\x8b\xa7"	// U+f2e7
#define ICON_FA_UTENSILS_ALT "\xef\x8b\xa6"	// U+f2e6
#define ICON_FA_VACUUM "\xef\xa5\x8d"	// U+f94d
#define ICON_FA_VACUUM_ROBOT "\xef\xa5\x8e"	// U+f94e
#define ICON_FA_VALUE_ABSOLUTE "\xef\x9a\xa6"	// U+f6a6
#define ICON_FA_VECTOR_SQUARE "\xef\x97\x8b"	// U+f5cb
#define ICON_FA_VENUS "\xef\x88\xa1"	// U+f221
#define ICON_FA_VENUS_DOUBLE "\xef\x88\xa6"	// U+f226
#define ICON_FA_VENUS_MARS "\xef\x88\xa8"	// U+f228
#define ICON_FA_VHS "\xef\xa3\xac"	// U+f8ec
#define ICON_FA_VIAL "\xef\x92\x92"	// U+f492
#define ICON_FA_VIALS "\xef\x92\x93"	// U+f493
#define ICON_FA_VIDEO "\xef\x80\xbd"	// U+f03d
#define ICON_FA_VIDEO_PLUS "\xef\x93\xa1"	// U+f4e1
#define ICON_FA_VIDEO_SLASH "\xef\x93\xa2"	// U+f4e2
#define ICON_FA_VIHARA "\xef\x9a\xa7"	// U+f6a7
#define ICON_FA_VIOLIN "\xef\xa3\xad"	// U+f8ed
#define ICON_FA_VOICEMAIL "\xef\xa2\x97"	// U+f897
#define ICON_FA_VOLCANO "\xef\x9d\xb0"	// U+f770
#define ICON_FA_VOLLEYBALL_BALL "\xef\x91\x9f"	// U+f45f
#define ICON_FA_VOLUME "\xef\x9a\xa8"	// U+f6a8
#define ICON_FA_VOLUME_DOWN "\xef\x80\xa7"	// U+f027
#define ICON_FA_VOLUME_MUTE "\xef\x9a\xa9"	// U+f6a9
#define ICON_FA_VOLUME_OFF "\xef\x80\xa6"	// U+f026
#define ICON_FA_VOLUME_SLASH "\xef\x8b\xa2"	// U+f2e2
#define ICON_FA_VOLUME_UP "\xef\x80\xa8"	// U+f028
#define ICON_FA_VOTE_NAY "\xef\x9d\xb1"	// U+f771
#define ICON_FA_VOTE_YEA "\xef\x9d\xb2"	// U+f772
#define ICON_FA_VR_CARDBOARD "\xef\x9c\xa9"	// U+f729
#define ICON_FA_WAGON_COVERED "\xef\xa3\xae"	// U+f8ee
#define ICON_FA_WALKER "\xef\xa0\xb1"	// U+f831
#define ICON_FA_WALKIE_TALKIE "\xef\xa3\xaf"	// U+f8ef
#define ICON_FA_WALKING "\xef\x95\x94"	// U+f554
#define ICON_FA_WALLET "\xef\x95\x95"	// U+f555
#define ICON_FA_WAND "\xef\x9c\xaa"	// U+f72a
#define ICON_FA_WAND_MAGIC "\xef\x9c\xab"	// U+f72b
#define ICON_FA_WAREHOUSE "\xef\x92\x94"	// U+f494
#define ICON_FA_WAREHOUSE_ALT "\xef\x92\x95"	// U+f495
#define ICON_FA_WASHER "\xef\xa2\x98"	// U+f898
#define ICON_FA_WATCH "\xef\x8b\xa1"	// U+f2e1
#define ICON_FA_WATCH_CALCULATOR "\xef\xa3\xb0"	// U+f8f0
#define ICON_FA_WATCH_FITNESS "\xef\x98\xbe"	// U+f63e
#define ICON_FA_WATER "\xef\x9d\xb3"	// U+f773
#define ICON_FA_WATER_LOWER "\xef\x9d\xb4"	// U+f774
#define ICON_FA_WATER_RISE "\xef\x9d\xb5"	// U+f775
#define ICON_FA_WAVE_SINE "\xef\xa2\x99"	// U+f899
#define ICON_FA_WAVE_SQUARE "\xef\xa0\xbe"	// U+f83e
#define ICON_FA_WAVE_TRIANGLE "\xef\xa2\x9a"	// U+f89a
#define ICON_FA_WAVEFORM "\xef\xa3\xb1"	// U+f8f1
#define ICON_FA_WAVEFORM_PATH "\xef\xa3\xb2"	// U+f8f2
#define ICON_FA_WEBCAM "\xef\xa0\xb2"	// U+f832
#define ICON_FA_WEBCAM_SLASH "\xef\xa0\xb3"	// U+f833
#define ICON_FA_WEIGHT "\xef\x92\x96"	// U+f496
#define ICON_FA_WEIGHT_HANGING "\xef\x97\x8d"	// U+f5cd
#define ICON_FA_WHALE "\xef\x9c\xac"	// U+f72c
#define ICON_FA_WHEAT "\xef\x9c\xad"	// U+f72d
#define ICON_FA_WHEELCHAIR "\xef\x86\x93"	// U+f193
#define ICON_FA_WHISTLE "\xef\x91\xa0"	// U+f460
#define ICON_FA_WIFI "\xef\x87\xab"	// U+f1eb
#define ICON_FA_WIFI_1 "\xef\x9a\xaa"	// U+f6aa
#define ICON_FA_WIFI_2 "\xef\x9a\xab"	// U+f6ab
#define ICON_FA_WIFI_SLASH "\xef\x9a\xac"	// U+f6ac
#define ICON_FA_WIND "\xef\x9c\xae"	// U+f72e
#define ICON_FA_WIND_TURBINE "\xef\xa2\x9b"	// U+f89b
#define ICON_FA_WIND_WARNING "\xef\x9d\xb6"	// U+f776
#define ICON_FA_WINDOW "\xef\x90\x8e"	// U+f40e
#define ICON_FA_WINDOW_ALT "\xef\x90\x8f"	// U+f40f
#define ICON_FA_WINDOW_CLOSE "\xef\x90\x90"	// U+f410
#define ICON_FA_WINDOW_FRAME "\xef\xa5\x8f"	// U+f94f
#define ICON_FA_WINDOW_FRAME_OPEN "\xef\xa5\x90"	// U+f950
#define ICON_FA_WINDOW_MAXIMIZE "\xef\x8b\x90"	// U+f2d0
#define ICON_FA_WINDOW_MINIMIZE "\xef\x8b\x91"	// U+f2d1
#define ICON_FA_WINDOW_RESTORE "\xef\x8b\x92"	// U+f2d2
#define ICON_FA_WINDSOCK "\xef\x9d\xb7"	// U+f777
#define ICON_FA_WINE_BOTTLE "\xef\x9c\xaf"	// U+f72f
#define ICON_FA_WINE_GLASS "\xef\x93\xa3"	// U+f4e3
#define ICON_FA_WINE_GLASS_ALT "\xef\x97\x8e"	// U+f5ce
#define ICON_FA_WON_SIGN "\xef\x85\x99"	// U+f159
#define ICON_FA_WREATH "\xef\x9f\xa2"	// U+f7e2
#define ICON_FA_WRENCH "\xef\x82\xad"	// U+f0ad
#define ICON_FA_X_RAY "\xef\x92\x97"	// U+f497
#define ICON_FA_YEN_SIGN "\xef\x85\x97"	// U+f157
#define ICON_FA_YIN_YANG "\xef\x9a\xad"	// U+f6ad
